@@ -39,7 +39,7 @@
 #include <gtk/gtk.h>
 #include <gdk/gdkx.h>
 #include <X11/keysym.h>
-#include <proplist.h>
+#include "proplist_t.h"
 
 #include "keys.h"
 #include "misc.h"
@@ -53,7 +53,7 @@
 *******************************************************************************/
 
 extern GtkWidget  *main_window;		/* from window.c */
-extern proplist_t *windowmaker;		/* from window.c */
+extern proplist_t windowmaker;		/* from window.c */
 
 /*******************************************************************************
 
@@ -364,8 +364,8 @@ update_keywidget (key_widget_t *kw, const char *keytext)
 	 gtk_widget_set_sensitive (kw->mod [n], number);   
 
    {
-      proplist_t *plmod  = PLMakeString ("ModifierKey");
-      char	 *modkey = PLGetString (PLGetDictionaryEntry (windowmaker,
+      proplist_t plmod  = WMCreatePLString ("ModifierKey");
+      char	 *modkey = WMGetFromPLString (WMGetFromPLDictionary (windowmaker,
 							      plmod));
       
       for (n = 0; n < 5; n++)
@@ -384,7 +384,7 @@ update_keywidget (key_widget_t *kw, const char *keytext)
 	 }
       }
    
-      PLRelease (plmod);
+      WMReleasePropList (plmod);
    }
    
    gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (kw->shift), shift);
@@ -528,8 +528,10 @@ keysym_list (void)
 	 if (name)
 	 {
 	    keyname [k] = g_strdup (name);
+#if 0
 	    if (isalpha (*keyname [k]))
 	       *keyname [k] = toupper (*keyname [k]);
+#endif
 	    k++;
 	 }
       }
