@@ -21,9 +21,9 @@
  */
 
 /*
- *  $Date: 2000/09/03 19:22:03 $
+ *  $Date: 2001/03/16 16:51:43 $
  *  $Author: hafner $
- *  $Revision: 1.37 $
+ *  $Revision: 1.38 $
  *  $State: Exp $
  */
 
@@ -45,7 +45,7 @@
 #include "themebrowser.h"
 #include "error.h"
 
-#define HOMEPAGE "http://ulli.linuxave.net/wmakerconf/"
+#define HOMEPAGE "http://freshmeat.net/wmakerconf"
 
 /*****************************************************************************
 
@@ -53,11 +53,13 @@
   
 *****************************************************************************/
 
-extern proplist_t *orig_wmaker;		/* original WindowMaker file */
-extern proplist_t *plist_changed;
-extern proplist_t *pl_yes;
+extern char       *orig_wmaker_fname;
+extern char       *orig_rootmenu_fname;
+extern proplist_t orig_wmaker;		/* original WindowMaker file */
+extern proplist_t plist_changed;
+extern proplist_t pl_yes;
 
-extern proplist_t  *orig_rootmenu;	/* original WMRootMenu file */
+extern proplist_t  orig_rootmenu;	/* original WMRootMenu file */
 extern GtkWidget   *log_text;
 extern GtkTooltips *tooltips;
 
@@ -182,13 +184,9 @@ make_menubar (GtkWidget *logwindow, bool_t show_themes_menu, bool_t noinet)
 			      GTK_SIGNAL_FUNC (gtk_widget_show_all),
 			      GTK_OBJECT (logwindow));
 
+   
    if (show_themes_menu)
-   {
-      item = gtk_menu_item_new_with_label (_("Update previews"));
-      gtk_menu_append (GTK_MENU (themes_menu), item);
-      gtk_signal_connect (GTK_OBJECT (item), "activate",
-			  GTK_SIGNAL_FUNC (generate_previews), NULL);
-   }
+      generate_theme_menu (GTK_MENU(themes_menu));
 
 #if defined(NETSCAPE)
 
@@ -202,17 +200,17 @@ make_menubar (GtkWidget *logwindow, bool_t show_themes_menu, bool_t noinet)
       gtk_signal_connect (GTK_OBJECT (item), "activate",
 			  GTK_SIGNAL_FUNC (wwwpage), "http://wm.themes.org");
 
-      item = gtk_menu_item_new_with_label (_("Linuxberg themes"));
+      item = gtk_menu_item_new_with_label (_("LonelyMachines.org"));
       gtk_menu_append (GTK_MENU (themes_menu), item);
       gtk_signal_connect (GTK_OBJECT (item), "activate",
 			  GTK_SIGNAL_FUNC (wwwpage),
-			  "http://www.linuxberg.com/themes/");
+			  "http://lonelymachines.org/wm_themes.html");
 
-      item = gtk_menu_item_new_with_label (_("Largo's themes"));
+      item = gtk_menu_item_new_with_label (_("unknown_lamer's themes"));
       gtk_menu_append (GTK_MENU (themes_menu), item);
       gtk_signal_connect (GTK_OBJECT (item), "activate",
 			  GTK_SIGNAL_FUNC (wwwpage),
-			  "http://wm.current.nu/themes/");
+		"http://lamer.hackedtobits.com/linux/wmaker-themes.html");
    }
    if (!noinet)
    {
@@ -375,7 +373,7 @@ about (GtkWidget *w, gpointer ptr)
       }
       
       gtk_box_pack_start (GTK_BOX (GTK_DIALOG (window)->vbox),
-			  gtk_label_new ("Copyright (C) 1998-2000 "
+			  gtk_label_new ("Copyright (C) 1998-2001 "
 					 "Ullrich Hafner"),
 			  FALSE, FALSE, 5);
       gtk_box_pack_start (GTK_BOX (GTK_DIALOG (window)->vbox),
@@ -512,10 +510,10 @@ revert_and_exit (GtkWidget *w, gpointer ptr)
  *  No return value.
  */
 {
-   if (!PLSave (orig_wmaker, YES))
+   if (!WMWritePropListToFile (orig_wmaker, orig_wmaker_fname, YES))
       warning (_("Can't revert to backupfile of `WindowMaker'. "
 		 "Please manually revert from file WindowMaker.bak."));
-   if (orig_rootmenu && !PLSave (orig_rootmenu, YES))
+   if (orig_rootmenu && !WMWritePropListToFile (orig_rootmenu, orig_rootmenu_fname, YES))
       warning (_("Can't revert to backupfile of `WMRootMenu'. "
 		 "Please manually revert from file WMRootMenu.bak."));
    gtk_main_quit ();
@@ -556,15 +554,15 @@ enable_revert (void)
 }
 
 void
-toggle_save (bool_t enable, proplist_t *key)
+toggle_save (bool_t enable, proplist_t key)
 {
    gtk_widget_set_sensitive (save_menu, enable);
    gtk_widget_set_sensitive (save_button, enable);
    if (enable && key)
    {
-      PLInsertDictionaryEntry (plist_changed, key, pl_yes);
+      WMPutInPLDictionary (plist_changed, key, pl_yes);
 
-      if (strcaseeq (PLGetString (key), "ThemePath"))
+      if (strcaseeq (WMGetFromPLString (key), "ThemePath"))
 	 build_theme_list ();
    }
 }
