@@ -31,7 +31,7 @@
 #include "config.h"
 
 #include <gtk/gtk.h>
-#include <proplist.h>
+#include "proplist_t.h"
 
 #include "misc.h"
 #include "path.h"
@@ -39,8 +39,8 @@
 #include "menu.h"
 #include "error.h"
 
-extern proplist_t *windowmaker;
-extern proplist_t *wmconfig;
+extern proplist_t windowmaker;
+extern proplist_t wmconfig;
 extern bool_t	   changed;
 
 /*****************************************************************************
@@ -65,10 +65,10 @@ update_entry (GtkCList *clist, gint row, gint column,
 static void
 change_dir (GtkWidget *entry, gpointer data);
 static void
-update_path (proplist_t *key, gpointer ptr, proplist_t *value,
+update_path (proplist_t key, gpointer ptr, proplist_t value,
 	     const char *path);
 static void
-init_dir_list (GtkCList *clist, proplist_t *value);
+init_dir_list (GtkCList *clist, proplist_t value);
 
 /*****************************************************************************
 
@@ -77,8 +77,8 @@ init_dir_list (GtkCList *clist, proplist_t *value);
 *****************************************************************************/
 
 void
-path_dialog (GtkWidget *page, proplist_t *key, proplist_t *array,
-	     GtkTooltips *tooltips, proplist_t *info)
+path_dialog (GtkWidget *page, proplist_t key, proplist_t array,
+	     GtkTooltips *tooltips, proplist_t info)
 /*
  *  Generate path dialog widget.
  *  Associated wmaker attribute name is given by 'key'.
@@ -96,27 +96,27 @@ path_dialog (GtkWidget *page, proplist_t *key, proplist_t *array,
    /*
     *  Error handling
     */
-   if (array && !PLIsArray (array))	/* uups */
+   if (array && !WMIsPLArray (array))	/* uups */
    {
-      PLRelease (array);
+      WMReleasePropList (array);
       array = NULL;
    }
    if (!array)
    {
-      array = PLMakeArrayFromElements (PLMakeString ("/"), NULL);
-      PLInsertDictionaryEntry (windowmaker, key, array);
+      array = WMCreatePLArray (WMCreatePLString ("/"), NULL);
+      WMPutInPLDictionary (windowmaker, key, array);
    }
    
    {
-      proplist_t *pltitle    = PLMakeString ("Title");
-      proplist_t *keydef     = PLGetDictionaryEntry (wmconfig, key);
-      proplist_t *title_text = PLGetDictionaryEntry (keydef, pltitle);
+      proplist_t pltitle    = WMCreatePLString ("Title");
+      proplist_t keydef     = WMGetFromPLDictionary (wmconfig, key);
+      proplist_t title_text = WMGetFromPLDictionary (keydef, pltitle);
 
-      frame = gtk_frame_new (D_(PLGetString (title_text ? title_text : key)));
+      frame = gtk_frame_new (D_(WMGetFromPLString (title_text ? title_text : key)));
       gtk_frame_set_label_align (GTK_FRAME (frame), 0.5, 0.5);
       gtk_container_set_border_width (GTK_CONTAINER (frame), 5);
       
-      PLRelease (pltitle);
+      WMReleasePropList (pltitle);
    }
    
    hbox = gtk_hbox_new (FALSE, 0);
@@ -175,7 +175,7 @@ path_dialog (GtkWidget *page, proplist_t *key, proplist_t *array,
    entry = gtk_entry_new ();
    gtk_box_pack_start (GTK_BOX (hbox), entry, TRUE, TRUE, 0);
    if (info)
-      gtk_tooltips_set_tip (tooltips, entry, D_(PLGetString (info)), NULL);
+      gtk_tooltips_set_tip (tooltips, entry, D_(WMGetFromPLString (info)), NULL);
    
    gtk_signal_connect (GTK_OBJECT (clist), "select_row",
 		       GTK_SIGNAL_FUNC (update_entry), entry);
@@ -183,7 +183,7 @@ path_dialog (GtkWidget *page, proplist_t *key, proplist_t *array,
    gtk_signal_connect_after (GTK_OBJECT (clist), "row_move",
 			     GTK_SIGNAL_FUNC (row_moved), clist);
 
-   init_dir_list (GTK_CLIST (clist), PLGetDictionaryEntry (windowmaker, key));
+   init_dir_list (GTK_CLIST (clist), WMGetFromPLDictionary (windowmaker, key));
    
    gtk_signal_connect (GTK_OBJECT (entry), "changed",
 		       GTK_SIGNAL_FUNC (change_dir), clist);
@@ -201,14 +201,14 @@ path_dialog (GtkWidget *page, proplist_t *key, proplist_t *array,
 *******************************************************************************/
 
 static void
-init_dir_list (GtkCList *clist, proplist_t *value)
+init_dir_list (GtkCList *clist, proplist_t value)
 {
    unsigned	i;
       
    gtk_clist_clear (GTK_CLIST (clist));
-   for (i = 0; i < PLGetNumberOfElements (value); i++)
+   for (i = 0; i < WMGetPropListItemCount (value); i++)
    {
-      char *text = PLGetString (PLGetArrayElement (value, i));
+      char *text = WMGetFromPLString (WMGetFromPLArray (value, i));
 	 
       gtk_clist_insert (GTK_CLIST (clist), i, &text);
    }
@@ -336,19 +336,19 @@ update_proplist (GtkWidget *button, gpointer data)
  */
 {
    GtkWidget	*clist = (GtkWidget *) data;
-   proplist_t	*key   = gtk_object_get_user_data (GTK_OBJECT (clist));
-   proplist_t	*array = PLGetDictionaryEntry (windowmaker, key);
+   proplist_t	key   = gtk_object_get_user_data (GTK_OBJECT (clist));
+   proplist_t	array = WMGetFromPLDictionary (windowmaker, key);
    int		n;
 
-   for (n = PLGetNumberOfElements (array); n; n--)
-      PLRemoveArrayElement (array, 0);
+   for (n = WMGetPropListItemCount (array); n; n--)
+      WMDeleteFromPLArray (array, 0);
    
    for (n = 0; n < GTK_CLIST (clist)->rows; n++)
    {
       char *text;
       
       gtk_clist_get_text (GTK_CLIST (clist), n, 0, &text);
-      PLInsertArrayElement (array, PLMakeString (text), n);
+      WMInsertInPLArray (array, n, WMCreatePLString (text));
    }
    toggle_save (changed = YES, key);
 }
@@ -392,9 +392,9 @@ change_dir (GtkWidget *entry, gpointer data)
 }
 
 static void
-update_path (proplist_t *key, gpointer ptr, proplist_t *value,
+update_path (proplist_t key, gpointer ptr, proplist_t value,
 	     const char *path)
 {
-   if (PLIsArray (value))
+   if (WMIsPLArray (value))
       init_dir_list (GTK_CLIST (ptr), value);
 }
