@@ -21,9 +21,9 @@
  */
 
 /*
- *  $Date: 2000/04/02 17:27:56 $
+ *  $Date: 2000/10/16 18:24:42 $
  *  $Author: hafner $
- *  $Revision: 1.11 $
+ *  $Revision: 1.12 $
  *  $State: Exp $
  */
 
@@ -43,7 +43,7 @@
 #include <gtk/gtk.h>
 #include <gdk/gdkx.h>
 #include <assert.h>
-#include <proplist.h>
+#include "proplist_t.h"
 #include <wraster.h>
 
 #include "window.h"
@@ -111,20 +111,20 @@ make_image (const char *filename, int width, int height, GtkWidget *preview)
    RImage *rimage = rimage_load (filename, width, height);
    
    preview = rimage_2_preview (rimage, preview, FALSE);
-   RDestroyImage (rimage);
+   RReleaseImage (rimage);
 
    return preview;
 }
 
 GtkWidget *
-make_gradient (proplist_t *array, unsigned width, unsigned height,
+make_gradient (proplist_t array, unsigned width, unsigned height,
 	       gtype_e type, GtkWidget *preview)
 {
-   if (!array || !PLIsArray (array) || PLGetNumberOfElements (array) < 3)
+   if (!array || !WMIsPLArray (array) || WMGetPropListItemCount (array) < 3)
       return make_image (PKGDATADIR "/black.xpm", width, height, preview);
    else
    {
-      unsigned	n 	 = PLGetNumberOfElements (array);
+      unsigned	n 	 = WMGetPropListItemCount (array);
       unsigned  start	 = n == 3 ? 1 : 2;
       RColor	**colors = Calloc (n + 1, sizeof (RColor *));
       unsigned	k;
@@ -133,7 +133,7 @@ make_gradient (proplist_t *array, unsigned width, unsigned height,
       {
 	 GdkColor c;
 	 
-	 if (!gdk_color_parse (PLGetString (PLGetArrayElement (array, k)), &c))
+	 if (!gdk_color_parse (WMGetFromPLString (WMGetFromPLArray (array, k)), &c))
 	    c.red = c.green = c.blue = 65535; /* white */
 
 	 colors [k - start]        = Calloc (1, sizeof (RColor)) ;
@@ -160,7 +160,7 @@ make_gradient (proplist_t *array, unsigned width, unsigned height,
 					  : RDiagonalGradient));
 	 preview = rimage_2_preview (rimage, preview,
 				     TRUE && rimage->height < 100);
-	 RDestroyImage (rimage);
+	 RReleaseImage (rimage);
       }
 
       for (k = start; k < n; k++)
@@ -211,23 +211,23 @@ make_solid (const char *color, unsigned width, unsigned height,
 }
 
 GtkWidget *
-make_textured_gradient (const char *filename, proplist_t *array,
+make_textured_gradient (const char *filename, proplist_t array,
 			unsigned width, unsigned height,
 			gtype_e type, GtkWidget *preview)
 {
-   if (!filename || PLGetNumberOfElements (array) != 5)
+   if (!filename || WMGetPropListItemCount (array) != 5)
       return make_image (PKGDATADIR "/black.xpm", width, height, preview);
    else
    {
       GdkColor	c1, c2;
       RColor	r1, r2;
-      int	opacity = strtol (PLGetString (PLGetArrayElement (array, 2)),
+      int	opacity = strtol (WMGetFromPLString (WMGetFromPLArray (array, 2)),
 				  NULL, 10);
       RImage	*gradient, *image, *tiled;
       
-      if (!gdk_color_parse (PLGetString (PLGetArrayElement (array, 3)), &c1))
+      if (!gdk_color_parse (WMGetFromPLString (WMGetFromPLArray (array, 3)), &c1))
 	 c1.red = c1.green = c1.blue = 65535; /* white */
-      if (!gdk_color_parse (PLGetString (PLGetArrayElement (array, 4)), &c2))
+      if (!gdk_color_parse (WMGetFromPLString (WMGetFromPLArray (array, 4)), &c2))
 	 c2.red = c2.green = c2.blue = 65535; /* white */
       r1.red   = c1.red >> 8;
       r1.green = c1.green >> 8;
@@ -255,50 +255,128 @@ make_textured_gradient (const char *filename, proplist_t *array,
 
       image = rimage_load (filename, -1, -1);
       tiled = RMakeTiledImage (image, width, height);
-      RDestroyImage (image);
+      RReleaseImage (image);
       
       if (tiled)
       {
 	 RCombineImagesWithOpaqueness (tiled, gradient, opacity);
-	 RDestroyImage (gradient);
+	 RReleaseImage (gradient);
 	 
 	 preview = rimage_2_preview (tiled, preview, FALSE);
-	 RDestroyImage (tiled);
+	 RReleaseImage (tiled);
       }
       else
       {
 	 preview = rimage_2_preview (gradient, preview, FALSE);
-	 RDestroyImage (gradient);
+	 RReleaseImage (gradient);
       }
       return preview;
    }
 }
 
+#ifdef HAVE_INTERWOVEN_GRADIENT
+
+GtkWidget *
+make_igradient (proplist_t array, unsigned width, unsigned height,
+		GtkWidget *preview)
+{
+   if (WMGetPropListItemCount (array) != 7)
+      return make_image (PKGDATADIR "/black.xpm", width, height, preview);
+   else
+   {
+      GdkColor	from1, to1, from2, to2;
+      RColor	r1 [2], r2 [2];
+      int	thickness1 = strtol (WMGetFromPLString (WMGetFromPLArray (array,
+								     3)),
+				     NULL, 10);
+      int	thickness2 = strtol (WMGetFromPLString (WMGetFromPLArray (array,
+								     6)),
+				     NULL, 10);
+      RImage	*gradient;
+      
+      if (!gdk_color_parse (WMGetFromPLString (WMGetFromPLArray (array, 1)),
+			    &from1))
+	 from1.red = from1.green = from1.blue = 65535; /* white */
+      if (!gdk_color_parse (WMGetFromPLString (WMGetFromPLArray (array, 2)), &to1))
+	 to1.red = to1.green = to1.blue = 65535; /* white */
+      if (!gdk_color_parse (WMGetFromPLString (WMGetFromPLArray (array, 4)),
+			    &from2))
+	 from2.red = from2.green = from2.blue = 65535; /* white */
+      if (!gdk_color_parse (WMGetFromPLString (WMGetFromPLArray (array, 5)), &to2))
+	 to2.red = to2.green = to2.blue = 65535; /* white */
+      
+      r1 [0].red   = from1.red >> 8;
+      r1 [0].green = from1.green >> 8;
+      r1 [0].blue  = from1.blue >> 8;
+
+      r1 [1].red   = to1.red >> 8;
+      r1 [1].green = to1.green >> 8;
+      r1 [1].blue  = to1.blue >> 8;
+
+      r2 [0].red   = from2.red >> 8;
+      r2 [0].green = from2.green >> 8;
+      r2 [0].blue  = from2.blue >> 8;
+
+      r2 [1].red   = to2.red >> 8;
+      r2 [1].green = to2.green >> 8;
+      r2 [1].blue  = to2.blue >> 8;
+
+      if (!preview)
+      {
+	 preview = gtk_preview_new (GTK_PREVIEW_COLOR);
+	 gtk_preview_size (GTK_PREVIEW (preview), width, height);
+      }
+      else
+      {
+	 width  = GTK_WIDGET (preview)->requisition.width;
+	 height = GTK_WIDGET (preview)->requisition.height;
+      }
+
+      gradient = RRenderInterwovenGradient (width, height,
+					    r1, thickness1,
+					    r2, thickness2);
+
+      if (gradient)
+      {
+	 preview = rimage_2_preview (gradient, preview,
+				     gradient->height < 100);
+	 RReleaseImage (gradient);
+      }
+      else
+	 preview = make_image (PKGDATADIR "/black.xpm",
+			       width, height, preview);
+
+      return preview;
+   }
+}
+
+#endif /* HAVE_INTERWOVEN_GRADIENT */
+
 #ifdef HAVE_LIBWMFUN
 GtkWidget *
-make_wmfun (proplist_t *array, unsigned width, unsigned height,
+make_wmfun (proplist_t array, unsigned width, unsigned height,
 	    GtkWidget *preview)
 {
-   unsigned n 		 = PLGetNumberOfElements (array);
+   unsigned n 		 = WMGetPropListItemCount (array);
    const char	*library = n > 2
-			   ? PLGetString (PLGetArrayElement (array, 1)) : NULL;
+			   ? WMGetFromPLString (WMGetFromPLArray (array, 1)) : NULL;
    const char	*type 	 = n > 2
-			   ? PLGetString (PLGetArrayElement (array, 0)) : NULL;
-   if (!array || !PLIsArray (array) || !library || !type ||
+			   ? WMGetFromPLString (WMGetFromPLArray (array, 0)) : NULL;
+   if (!array || !WMIsPLArray (array) || !library || !type ||
        !strcaseeq (type, "function") || !strncaseeq (library, "libwmfun",
 						     strlen ("libwmfun")))
       return make_image (PKGDATADIR "/black.xpm", width, height, preview);
    else
    {
-      unsigned	 n    	  = PLGetNumberOfElements (array);
+      unsigned	 n    	  = WMGetPropListItemCount (array);
       char     **argv 	  = Calloc (n + 2, sizeof (char *));
-      char 	*function = PLGetString (PLGetArrayElement (array, 2));
+      char 	*function = WMGetFromPLString (WMGetFromPLArray (array, 2));
       unsigned	 k;
       unsigned	 argc;
       RImage 	*image;
 
       for (k = 2, argc = 0; k < n; k++)
-	 argv [argc++] = PLGetString (PLGetArrayElement (array, k));
+	 argv [argc++] = WMGetFromPLString (WMGetFromPLArray (array, k));
       argv [argc] = NULL;
       
       if ((strcaseeq (function, "bilinear")))
@@ -312,9 +390,8 @@ make_wmfun (proplist_t *array, unsigned width, unsigned height,
 
       if (image)
       {
-	 preview = rimage_2_preview (image, preview,
-				     TRUE && image->height < 100);
-	 RDestroyImage (image);
+	 preview = rimage_2_preview (image, preview, image->height < 100);
+	 RReleaseImage (image);
       }
       else
 	 preview = make_image (PKGDATADIR "/black.xpm",
@@ -355,7 +432,7 @@ rimage_load (const char *filename, int width, int height)
 	 if (streq (filename, PKGDATADIR "/black.xpm"))
 	 {
 	    RImage *scaled = RScaleImage (image, width, height);
-	    RDestroyImage (image);
+	    RReleaseImage (image);
 	    image = scaled;
 	 }
 	 else if (image->width > (unsigned) width
@@ -369,7 +446,7 @@ rimage_load (const char *filename, int width, int height)
 	       width  = height * image->width / image->height;
 	    
 	    scaled = RScaleImage (image, max (width, 22), max (height, 22));
-	    RDestroyImage (image);
+	    RReleaseImage (image);
 	    image = scaled;
 	 }
       }
