@@ -32,7 +32,7 @@
 #include <stdio.h>
 
 #include <gtk/gtk.h>
-#include <proplist.h>
+#include "proplist_t.h"
 
 #include "simple.h"
 #include "dialog.h"
@@ -51,7 +51,7 @@
 *******************************************************************************/
 
 extern bool_t	  changed;		/* window.c */
-extern proplist_t *windowmaker;		/* window.c */
+extern proplist_t windowmaker;		/* window.c */
  
 /*******************************************************************************
 
@@ -73,7 +73,7 @@ color_toggle (GtkWidget *widget, gpointer ptr);
 static void
 show_color_buttons (text_color_t *text_color);
 static void
-update_text_color (proplist_t *key, gpointer ptr, proplist_t *value,
+update_text_color (proplist_t key, gpointer ptr, proplist_t value,
 		   const char *path);
 #endif /* HAVE_LIBWMFUN */
 static void
@@ -94,19 +94,19 @@ set_fontname (GtkWidget *widget, gpointer ptr);
 static void
 fontsel_dialog (GtkWidget *widget, gpointer ptr);
 static void
-update_entry (proplist_t *key, gpointer ptr, proplist_t *value,
+update_entry (proplist_t key, gpointer ptr, proplist_t value,
 	      const char *path);
 static void
-update_color (proplist_t *key, gpointer ptr, proplist_t *value,
+update_color (proplist_t key, gpointer ptr, proplist_t value,
 	      const char *path);
 static void
-update_boolean (proplist_t *key, gpointer ptr, proplist_t *value,
+update_boolean (proplist_t key, gpointer ptr, proplist_t value,
 		const char *path);
 static void
-update_iboolean (proplist_t *key, gpointer ptr, proplist_t *value,
+update_iboolean (proplist_t key, gpointer ptr, proplist_t value,
 		 const char *path);
 static void
-update_int (proplist_t *key, gpointer ptr, proplist_t *value,
+update_int (proplist_t key, gpointer ptr, proplist_t value,
 	    const char *path);
 
 /*******************************************************************************
@@ -116,10 +116,10 @@ update_int (proplist_t *key, gpointer ptr, proplist_t *value,
 *******************************************************************************/
 
 void
-boolean_dialog (GtkWidget *table, proplist_t *key, proplist_t *value,
-		proplist_t *info)
+boolean_dialog (GtkWidget *table, proplist_t key, proplist_t value,
+		proplist_t info)
 {
-   GtkWidget *label  = gtk_label_new (D_(PLGetString (info)));
+   GtkWidget *label  = gtk_label_new (D_(WMGetFromPLString (info)));
    GtkWidget *button = gtk_check_button_new ();
 
    gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (button),
@@ -132,10 +132,10 @@ boolean_dialog (GtkWidget *table, proplist_t *key, proplist_t *value,
 }
 
 void
-iboolean_dialog (GtkWidget *table, proplist_t *key, proplist_t *value,
-		 proplist_t *info)
+iboolean_dialog (GtkWidget *table, proplist_t key, proplist_t value,
+		 proplist_t info)
 {
-   GtkWidget *label  = gtk_label_new (D_(PLGetString (info)));
+   GtkWidget *label  = gtk_label_new (D_(WMGetFromPLString (info)));
    GtkWidget *button = gtk_check_button_new ();
 
    gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (button),
@@ -148,22 +148,22 @@ iboolean_dialog (GtkWidget *table, proplist_t *key, proplist_t *value,
 }
 
 void
-string_dialog (GtkWidget *table, proplist_t *key, proplist_t *value,
-	       proplist_t *range, proplist_t *rinfo, proplist_t *info)
+string_dialog (GtkWidget *table, proplist_t key, proplist_t value,
+	       proplist_t range, proplist_t rinfo, proplist_t info)
 {
    GtkWidget	*option_menu;
-   GtkWidget	*label = gtk_label_new (D_(PLGetString (info)));
+   GtkWidget	*label = gtk_label_new (D_(WMGetFromPLString (info)));
    const char	**values;
    unsigned	n, current = 0;
    
-   values = Calloc (PLGetNumberOfElements (range) + 1, sizeof (char *));
-   for (n = 0; n < PLGetNumberOfElements (range); n++)
+   values = Calloc (WMGetPropListItemCount (range) + 1, sizeof (char *));
+   for (n = 0; n < WMGetPropListItemCount (range); n++)
    {
-      proplist_t *element = PLGetArrayElement (range, n);
+      proplist_t element = WMGetFromPLArray (range, n);
 	       
-      if (strcaseeq (PLGetString (element), PLGetString (value)))
+      if (strcaseeq (WMGetFromPLString (element), WMGetFromPLString (value)))
 	 current = n;
-      values [n] = PLGetString (element);
+      values [n] = WMGetFromPLString (element);
    }
    values [n] = NULL;
 		  
@@ -181,27 +181,27 @@ string_dialog (GtkWidget *table, proplist_t *key, proplist_t *value,
 }
 
 void
-int_dialog (GtkWidget *table, proplist_t *key, proplist_t *value,
-	    proplist_t *range, proplist_t *rinfo, proplist_t *info)
+int_dialog (GtkWidget *table, proplist_t key, proplist_t value,
+	    proplist_t range, proplist_t rinfo, proplist_t info)
 {
-   GtkWidget    *label 	= gtk_label_new (D_(PLGetString (info)));
+   GtkWidget    *label 	= gtk_label_new (D_(WMGetFromPLString (info)));
    GtkWidget    *hbox  	= gtk_hbox_new (FALSE, 5);
-   GtkEntry	**array = Calloc (PLGetNumberOfElements (range) / 2 + 1,
+   GtkEntry	**array = Calloc (WMGetPropListItemCount (range) / 2 + 1,
 				  sizeof (GtkEntry *));
    unsigned	n;
    
-   for (n = 0; n < PLGetNumberOfElements (range); n += 2)
+   for (n = 0; n < WMGetPropListItemCount (range); n += 2)
    {
       GtkWidget *spinner;
       GtkObject *adj;
-      char	*m = PLGetString (PLGetArrayElement (range, n));
-      char	*M = PLGetString (PLGetArrayElement (range, n + 1));
+      char	*m = WMGetFromPLString (WMGetFromPLArray (range, n));
+      char	*M = WMGetFromPLString (WMGetFromPLArray (range, n + 1));
       char 	*v;
 	       
-      if (PLIsArray (value))
-	 v = PLGetString (PLGetArrayElement (value, n / 2));
+      if (WMIsPLArray (value))
+	 v = WMGetFromPLString (WMGetFromPLArray (value, n / 2));
       else
-	 v = PLGetString (value);
+	 v = WMGetFromPLString (value);
 	       
       adj = gtk_adjustment_new (strtod (v, NULL),
 				strtod (m, NULL), strtod (M, NULL),
@@ -231,14 +231,14 @@ int_dialog (GtkWidget *table, proplist_t *key, proplist_t *value,
 }
 
 void
-text_dialog (GtkWidget *table, proplist_t *key, proplist_t *value,
-	     proplist_t *info)
+text_dialog (GtkWidget *table, proplist_t key, proplist_t value,
+	     proplist_t info)
 {
    GtkWidget *entry = gtk_entry_new ();
-   GtkWidget *label = gtk_label_new (D_(PLGetString (info)));
+   GtkWidget *label = gtk_label_new (D_(WMGetFromPLString (info)));
 		  
    gtk_widget_set_usize (entry, 100, 0);
-   gtk_entry_set_text (GTK_ENTRY (entry), PLGetString (value));
+   gtk_entry_set_text (GTK_ENTRY (entry), WMGetFromPLString (value));
    gtk_signal_connect (GTK_OBJECT (entry), "changed",
 		       GTK_SIGNAL_FUNC (set_entry_text), key);
    append_dialog (table, entry, label, GTK_FILL | GTK_SHRINK);
@@ -246,11 +246,11 @@ text_dialog (GtkWidget *table, proplist_t *key, proplist_t *value,
 }
 
 GtkWidget *
-font_dialog (GtkWidget *page, proplist_t *key, proplist_t *value,
-	     proplist_t *info)
+font_dialog (GtkWidget *page, proplist_t key, proplist_t value,
+	     proplist_t info)
 {
    GtkWidget *entry  = gtk_entry_new ();
-   GtkWidget *frame  = gtk_frame_new (D_(PLGetString (info)));
+   GtkWidget *frame  = gtk_frame_new (D_(WMGetFromPLString (info)));
    GtkWidget *hbox   = gtk_hbox_new (FALSE, 0);
    GtkWidget *bbox   = gtk_hbutton_box_new ();
    GtkWidget *button = gtk_button_new_with_label (_("Browse..."));
@@ -259,7 +259,7 @@ font_dialog (GtkWidget *page, proplist_t *key, proplist_t *value,
    gtk_frame_set_shadow_type (GTK_FRAME (frame), GTK_SHADOW_ETCHED_IN);
    gtk_container_add (GTK_CONTAINER (frame), hbox);
 
-   gtk_entry_set_text (GTK_ENTRY (entry), PLGetString (value));
+   gtk_entry_set_text (GTK_ENTRY (entry), WMGetFromPLString (value));
    gtk_signal_connect (GTK_OBJECT (entry), "changed",
 		       GTK_SIGNAL_FUNC (set_entry_text), key);
    gtk_box_pack_start (GTK_BOX (hbox), entry, TRUE, TRUE, 5);
@@ -278,18 +278,18 @@ font_dialog (GtkWidget *page, proplist_t *key, proplist_t *value,
 }
 
 GtkWidget *
-color_dialog (GtkWidget *page, proplist_t *key, proplist_t *value,
-	      GtkTooltips *tooltips, proplist_t *info, proplist_t *title)
+color_dialog (GtkWidget *page, proplist_t key, proplist_t value,
+	      GtkTooltips *tooltips, proplist_t info, proplist_t title)
 {
    GtkWidget *frame;
    GtkWidget *button = color_button (NULL, key, value, tooltips,
-				     D_(PLGetString (info)));
+				     D_(WMGetFromPLString (info)));
    GtkWidget *hbox = gtk_hbox_new (TRUE, 0);
 
    if (title)
-      frame = gtk_frame_new (D_(PLGetString (title)));
+      frame = gtk_frame_new (D_(WMGetFromPLString (title)));
    else
-      frame = gtk_frame_new (PLGetString (key));
+      frame = gtk_frame_new (WMGetFromPLString (key));
 
    gtk_container_set_border_width (GTK_CONTAINER (hbox), 5);
    gtk_frame_set_label_align (GTK_FRAME (frame), 0.5, 0.5);
@@ -308,8 +308,8 @@ color_dialog (GtkWidget *page, proplist_t *key, proplist_t *value,
 
 #ifdef HAVE_LIBWMFUN
 GtkWidget *
-extended_color_dialog (GtkWidget *page, proplist_t *key, proplist_t *value,
-		       GtkTooltips *tooltips, proplist_t *info, proplist_t *title)
+extended_color_dialog (GtkWidget *page, proplist_t key, proplist_t value,
+		       GtkTooltips *tooltips, proplist_t info, proplist_t title)
 {
    GtkWidget   	*frame;
    GtkWidget   	*option_menu;
@@ -367,17 +367,17 @@ extended_color_dialog (GtkWidget *page, proplist_t *key, proplist_t *value,
 #endif /* HAVE_LIBWMFUN */
 
 void
-update_optionmenu (proplist_t *key, gpointer ptr, proplist_t *value,
+update_optionmenu (proplist_t key, gpointer ptr, proplist_t value,
 		   const char *path)
 {
    omenudata_t *data = (omenudata_t *) ptr;
 
-   if (PLIsString (value))
-      set_option_menu_default (data->omenu, data->values, PLGetString (value));
+   if (WMIsPLString (value))
+      set_option_menu_default (data->omenu, data->values, WMGetFromPLString (value));
 }
 
 bool_t
-convert_bool (proplist_t *p)
+convert_bool (proplist_t p)
 /*
  *  Parse boolean values of WindowMaker file.
  *
@@ -387,9 +387,9 @@ convert_bool (proplist_t *p)
 {
    char *val;
 
-   assert (p && PLIsSimple (p));
+   assert (p && (WMIsPLString (p) || WMIsPLData (p)));
 
-   val = PLGetString (p);
+   val = WMGetFromPLString (p);
 
    if (strcaseeq (val, "y") || strcaseeq (val, "yes")
        || strcaseeq (val, "t") || strcaseeq (val, "true")
@@ -418,31 +418,31 @@ color_toggle (GtkWidget *widget, gpointer ptr)
 {
    char 	*text 	    = gtk_object_get_user_data (GTK_OBJECT (widget));
    text_color_t *text_color = (text_color_t *) ptr;
-   proplist_t 	*value 	    = PLGetDictionaryEntry (windowmaker, text_color->key);
+   proplist_t 	value 	    = WMGetFromPLDictionary (windowmaker, text_color->key);
    
    if (text == color_types [TCOLOR_SIMPLE])
    {
-      if (!PLIsString (value))
+      if (!WMIsPLString (value))
       {
-	 PLInsertDictionaryEntry (windowmaker, text_color->key,
-				  PLMakeString ("tan"));
+	 WMPutInPLDictionary (windowmaker, text_color->key,
+				  WMCreatePLString ("tan"));
 	 toggle_save (changed = YES, text_color->key);
 	 show_color_buttons (text_color);
       }
    }
    else
    {
-      if (!PLIsArray (value))
+      if (!WMIsPLArray (value))
       {
-	 proplist_t *pl;
-	 pl = PLMakeArrayFromElements (PLMakeString ("function"),
-				       PLMakeString ("libwmfun.so"),
-				       PLMakeString ("drawPlainString"),
-				       PLMakeString ("white"),
-				       PLMakeString ("black"),
-				       PLMakeString ("red"), NULL);
+	 proplist_t pl;
+	 pl = WMCreatePLArray (WMCreatePLString ("function"),
+				       WMCreatePLString ("libwmfun.so"),
+				       WMCreatePLString ("drawPlainString"),
+				       WMCreatePLString ("white"),
+				       WMCreatePLString ("black"),
+				       WMCreatePLString ("red"), NULL);
       
-	 PLInsertDictionaryEntry (windowmaker, text_color->key, pl);
+	 WMPutInPLDictionary (windowmaker, text_color->key, pl);
 	 toggle_save (changed = YES, text_color->key);
 	 show_color_buttons (text_color);
       }
@@ -452,27 +452,27 @@ color_toggle (GtkWidget *widget, gpointer ptr)
 static void
 show_color_buttons (text_color_t *text_color)
 {
-   proplist_t *value = PLGetDictionaryEntry (windowmaker, text_color->key);
+   proplist_t value = WMGetFromPLDictionary (windowmaker, text_color->key);
    
-   if (PLIsArray (value))		/* check syntax of value */
+   if (WMIsPLArray (value))		/* check syntax of value */
    {
-      if (!(PLGetNumberOfElements (value) == 6
-	    && strcaseeq (PLGetString (PLGetArrayElement (value, 0)),
+      if (!(WMGetPropListItemCount (value) == 6
+	    && strcaseeq (WMGetFromPLString (WMGetFromPLArray (value, 0)),
 			  "function")
-	    && strncaseeq (PLGetString (PLGetArrayElement (value, 1)),
+	    && strncaseeq (WMGetFromPLString (WMGetFromPLArray (value, 1)),
 			   "libwmfun", strlen ("libwmfun"))
-	    && strcaseeq (PLGetString (PLGetArrayElement (value, 2)),
+	    && strcaseeq (WMGetFromPLString (WMGetFromPLArray (value, 2)),
 			  "drawPlainString")))
       {
-	 proplist_t *pl;
-	 pl = PLMakeArrayFromElements (PLMakeString ("function"),
-				       PLMakeString ("libwmfun.so"),
-				       PLMakeString ("drawPlainString"),
-				       PLMakeString ("white"),
-				       PLMakeString ("black"),
-				       PLMakeString ("red"), NULL);
+	 proplist_t pl;
+	 pl = WMCreatePLArray (WMCreatePLString ("function"),
+				       WMCreatePLString ("libwmfun.so"),
+				       WMCreatePLString ("drawPlainString"),
+				       WMCreatePLString ("white"),
+				       WMCreatePLString ("black"),
+				       WMCreatePLString ("red"), NULL);
 	 
-	 PLInsertDictionaryEntry (windowmaker, text_color->key, pl);
+	 WMPutInPLDictionary (windowmaker, text_color->key, pl);
 	 value = pl;
       }
       set_option_menu_default (GTK_OPTION_MENU (text_color->option_menu),
@@ -485,14 +485,14 @@ show_color_buttons (text_color_t *text_color)
 	 GtkWidget *preview;
 
 	 preview = gtk_object_get_user_data (GTK_OBJECT (text_color->color_set [0]));
-	 fill_preview (GTK_PREVIEW (preview), PLGetString (PLGetArrayElement (value, 3)));
-	 gtk_object_set_user_data (GTK_OBJECT (preview), PLGetArrayElement (value, 3));
+	 fill_preview (GTK_PREVIEW (preview), WMGetFromPLString (WMGetFromPLArray (value, 3)));
+	 gtk_object_set_user_data (GTK_OBJECT (preview), WMGetFromPLArray (value, 3));
 	 preview = gtk_object_get_user_data (GTK_OBJECT (text_color->color_set [1]));
-	 fill_preview (GTK_PREVIEW (preview), PLGetString (PLGetArrayElement (value, 4)));
-	 gtk_object_set_user_data (GTK_OBJECT (preview), PLGetArrayElement (value, 4));
+	 fill_preview (GTK_PREVIEW (preview), WMGetFromPLString (WMGetFromPLArray (value, 4)));
+	 gtk_object_set_user_data (GTK_OBJECT (preview), WMGetFromPLArray (value, 4));
 	 preview = gtk_object_get_user_data (GTK_OBJECT (text_color->color_set [2]));
-	 fill_preview (GTK_PREVIEW (preview), PLGetString (PLGetArrayElement (value, 5)));
-	 gtk_object_set_user_data (GTK_OBJECT (preview), PLGetArrayElement (value, 5));
+	 fill_preview (GTK_PREVIEW (preview), WMGetFromPLString (WMGetFromPLArray (value, 5)));
+	 gtk_object_set_user_data (GTK_OBJECT (preview), WMGetFromPLArray (value, 5));
       }
       gtk_widget_show (text_color->color_set [0]);
       gtk_widget_show (text_color->color_set [1]);
@@ -514,7 +514,7 @@ show_color_buttons (text_color_t *text_color)
 	 GtkWidget *preview;
 
 	 preview = gtk_object_get_user_data (GTK_OBJECT (text_color->solid_color));
-	 fill_preview (GTK_PREVIEW (preview), PLGetString (value));
+	 fill_preview (GTK_PREVIEW (preview), WMGetFromPLString (value));
 	 gtk_object_set_user_data (GTK_OBJECT (preview), value);
       }
    }
@@ -561,15 +561,15 @@ set_bool (GtkWidget *widget, gpointer ptr)
  *  No return value.
  */
 {
-   proplist_t *key  = (proplist_t *) ptr;
+   proplist_t key   = (proplist_t) ptr;
    char       *text = GTK_TOGGLE_BUTTON (widget)->active ? "Yes" : "No";
-   proplist_t *pl   = PLMakeString (text);
+   proplist_t pl    = WMCreatePLString (text);
    
-   PLInsertDictionaryEntry (windowmaker, key, pl);
-   PLRelease (pl);
+   WMPutInPLDictionary (windowmaker, key, pl);
+   WMReleasePropList (pl);
    toggle_save (changed = YES, key);
 
-   if (strcaseeq (PLGetString (key), "NewStyle"))
+   if (strcaseeq (WMGetFromPLString (key), "NewStyle"))
       check_widgetstyle ();
 }
 
@@ -581,15 +581,15 @@ set_ibool (GtkWidget *widget, gpointer ptr)
  *  No return value.
  */
 {
-   proplist_t *key  = (proplist_t *) ptr;
+   proplist_t key  = (proplist_t) ptr;
    char       *text = GTK_TOGGLE_BUTTON (widget)->active ? "No" : "Yes";
-   proplist_t *pl   = PLMakeString (text);
+   proplist_t pl   = WMCreatePLString (text);
    
-   PLInsertDictionaryEntry (windowmaker, key, pl);
-   PLRelease (pl);
+   WMPutInPLDictionary (windowmaker, key, pl);
+   WMReleasePropList (pl);
    toggle_save (changed = YES, key);
 
-   if (strcaseeq (PLGetString (key), "NewStyle"))
+   if (strcaseeq (WMGetFromPLString (key), "NewStyle"))
       check_widgetstyle ();
 }
 
@@ -601,12 +601,12 @@ set_string (GtkWidget *widget, gpointer ptr)
  *  No return value.
  */
 {
-   proplist_t *key  = (proplist_t *) ptr;
+   proplist_t key  = (proplist_t) ptr;
    char       *text = gtk_object_get_user_data (GTK_OBJECT (widget));
-   proplist_t *pl   = PLMakeString (text);
+   proplist_t pl   = WMCreatePLString (text);
    
-   PLInsertDictionaryEntry (windowmaker, key, pl);
-   PLRelease (pl);
+   WMPutInPLDictionary (windowmaker, key, pl);
+   WMReleasePropList (pl);
    toggle_save (changed = YES, key);
 }
 
@@ -618,7 +618,7 @@ set_int (GtkWidget *widget, gpointer ptr)
  *  No return value.
  */
 {
-   proplist_t	 *key = (proplist_t *) ptr;
+   proplist_t	 key = (proplist_t) ptr;
    GtkSpinButton *spinner;
    int		 val;
    char		 tmp [MAXSTRLEN];
@@ -628,21 +628,21 @@ set_int (GtkWidget *widget, gpointer ptr)
    
    sprintf (tmp, "%d", val);
 
-   if (PLIsArray (PLGetDictionaryEntry (windowmaker, key)))
+   if (WMIsPLArray (WMGetFromPLDictionary (windowmaker, key)))
    {
-      proplist_t *array = PLGetDictionaryEntry (windowmaker, key);
+      proplist_t array = WMGetFromPLDictionary (windowmaker, key);
       unsigned	 n;
       
       n = (GtkWidget *) gtk_object_get_user_data (GTK_OBJECT (spinner))
 	  - GTK_WIDGET (spinner);
-      PLRemoveArrayElement (array, n);
-      PLInsertArrayElement (array, PLMakeString (tmp), n);
+      WMDeleteFromPLArray (array, n);
+      WMInsertInPLArray (array, n, WMCreatePLString (tmp));
    }
    else
    {
-      proplist_t *pl = PLMakeString (tmp);
-      PLInsertDictionaryEntry (windowmaker, key, pl);
-      PLRelease (pl);
+      proplist_t pl = WMCreatePLString (tmp);
+      WMPutInPLDictionary (windowmaker, key, pl);
+      WMReleasePropList (pl);
    }
    
    toggle_save (changed = YES, key);
@@ -656,21 +656,21 @@ set_entry_text (GtkWidget *widget, gpointer ptr)
  *  No return value.
  */
 {
-   proplist_t *element;
-   proplist_t *key   = (proplist_t *) ptr;
-   proplist_t *array = PLGetDictionaryEntry (windowmaker, key);
+   proplist_t element;
+   proplist_t key   = (proplist_t) ptr;
+   proplist_t array = WMGetFromPLDictionary (windowmaker, key);
 
-   element = PLMakeString ((char *) gtk_entry_get_text (GTK_ENTRY (widget)));
+   element = WMCreatePLString ((char *) gtk_entry_get_text (GTK_ENTRY (widget)));
 
-   if (PLIsArray (array))
+   if (WMIsPLArray (array))
    {
-      PLRemoveArrayElement (array, 1);	/* filename */
-      PLInsertArrayElement (array, element, 1);
+      WMDeleteFromPLArray (array, 1);	/* filename */
+      WMInsertInPLArray (array, 1, element);
    }
    else
    {
-      PLInsertDictionaryEntry (windowmaker, key, element);
-      PLRelease (element);
+      WMPutInPLDictionary (windowmaker, key, element);
+      WMReleasePropList (element);
    }
    
    toggle_save (changed = YES, key);
@@ -728,41 +728,40 @@ set_fontname (GtkWidget *widget, gpointer ptr)
 }
 
 static void
-update_entry (proplist_t *key, gpointer ptr, proplist_t *value,
+update_entry (proplist_t key, gpointer ptr, proplist_t value,
 	      const char *path)
 {
-   if (PLIsString (value))
-      gtk_entry_set_text (GTK_ENTRY (ptr), PLGetString (value));
+   if (WMIsPLString (value))
+      gtk_entry_set_text (GTK_ENTRY (ptr), WMGetFromPLString (value));
 }
 
 static void
-update_color (proplist_t *key, gpointer ptr, proplist_t *value,
+update_color (proplist_t key, gpointer ptr, proplist_t value,
 	      const char *path)
 {
-   if (PLIsString (value))
+   if (WMIsPLString (value))
    {
       GtkWidget  *preview  = GTK_WIDGET (ptr);
-      proplist_t *oldvalue = gtk_object_get_user_data (GTK_OBJECT (preview));
+      proplist_t oldvalue  = gtk_object_get_user_data (GTK_OBJECT (preview));
 
-      PLRelease (oldvalue);
-      PLRetain (value);
+      WMRetainPropList (value);
       gtk_object_set_user_data (GTK_OBJECT (preview), value);
-      fill_preview (GTK_PREVIEW (preview), PLGetString (value));
-      PLInsertDictionaryEntry (windowmaker, key, value);
+      fill_preview (GTK_PREVIEW (preview), WMGetFromPLString (value));
+      WMPutInPLDictionary (windowmaker, key, value);
       toggle_save (changed = YES, key);
    }
 }
 
 #ifdef HAVE_LIBWMFUN
 static void
-update_text_color (proplist_t *key, gpointer ptr, proplist_t *value,
+update_text_color (proplist_t key, gpointer ptr, proplist_t value,
 		   const char *path)
 {
-   if (PLIsString (value) || PLIsArray (value))
+   if (WMIsPLString (value) || WMIsPLArray (value))
    {
       text_color_t *text_color = (text_color_t *) ptr;
 
-      PLInsertDictionaryEntry (windowmaker, key, value);
+      WMPutInPLDictionary (windowmaker, key, value);
       toggle_save (changed = YES, key);
       show_color_buttons (text_color);
    }
@@ -770,10 +769,10 @@ update_text_color (proplist_t *key, gpointer ptr, proplist_t *value,
 #endif /* HAVE_LIBWMFUN */
 
 static void
-update_boolean (proplist_t *key, gpointer ptr, proplist_t *value,
+update_boolean (proplist_t key, gpointer ptr, proplist_t value,
 		const char *path)
 {
-   if (PLIsString (value))
+   if (WMIsPLString (value))
    {
       gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (ptr),
 				    convert_bool (value));
@@ -782,10 +781,10 @@ update_boolean (proplist_t *key, gpointer ptr, proplist_t *value,
 }
 
 static void
-update_iboolean (proplist_t *key, gpointer ptr, proplist_t *value,
+update_iboolean (proplist_t key, gpointer ptr, proplist_t value,
 		 const char *path)
 {
-   if (PLIsString (value))
+   if (WMIsPLString (value))
    {
       gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (ptr),
 				    convert_bool (value) ? FALSE : TRUE);
@@ -794,21 +793,21 @@ update_iboolean (proplist_t *key, gpointer ptr, proplist_t *value,
 }
 
 static void
-update_int (proplist_t *key, gpointer ptr, proplist_t *value,
+update_int (proplist_t key, gpointer ptr, proplist_t value,
 	    const char *path)
 {
    GtkEntry **entry = (GtkEntry **) ptr;
    
-   if (PLIsString (value))
-      gtk_entry_set_text (entry [0], PLGetString (value));
-   else if (PLIsArray (value))
+   if (WMIsPLString (value))
+      gtk_entry_set_text (entry [0], WMGetFromPLString (value));
+   else if (WMIsPLArray (value))
    {
       unsigned n;
 
-      for (n = 0; n < PLGetNumberOfElements (value); n++)
+      for (n = 0; n < WMGetPropListItemCount (value); n++)
 	 if (entry [n])
 	    gtk_entry_set_text (entry [n],
-				PLGetString (PLGetArrayElement (value, n)));
+				WMGetFromPLString (WMGetFromPLArray (value, n)));
 	 else
 	    break;
    }
