@@ -44,7 +44,7 @@
 
 #include <stdio.h>
 #include <gtk/gtk.h>
-#include <proplist.h>
+#include "proplist_t.h"
 
 /* unistd.h defines _POSIX_VERSION on POSIX.1 systems. */
 #if defined(HAVE_DIRENT_H) || defined(_POSIX_VERSION)
@@ -95,11 +95,12 @@ bool_t	     use_imlib   = NO;
 GtkWidget   *main_window = NULL;
 GdkColor    *background  = NULL;
 GtkTooltips *tooltips    = NULL;
-proplist_t  *windowmaker = NULL;
-proplist_t  *wmconfig    = NULL;
+proplist_t   windowmaker = NULL;
+proplist_t   wmconfig    = NULL;
 
-extern proplist_t *plist_changed;
-extern proplist_t *pl_yes;
+extern char       *orig_wmaker_fname;
+extern proplist_t  plist_changed;
+extern proplist_t  pl_yes;
 
 GtkWidget *widgetstyle_item = NULL;
 
@@ -110,7 +111,7 @@ GtkWidget *widgetstyle_item = NULL;
 *****************************************************************************/
 
 void
-update (gpointer ptr, proplist_t *value);
+update (gpointer ptr, proplist_t value);
 static GtkWidget *
 create_page (GtkNotebook *notebook, const char *name, const char *pixmap_name,
 	     bool_t horizontal);
@@ -123,7 +124,7 @@ switch_subentries (GtkWidget *widget, gpointer ptr);
 static void
 init_option_menu (gpointer data, gpointer user_data);
 static void
-appearance_container (proplist_t *type, proplist_t *thispanel,
+appearance_container (proplist_t type, proplist_t thispanel,
 		      GList **options, GtkWidget *box);
 
 /*****************************************************************************
@@ -135,8 +136,8 @@ appearance_container (proplist_t *type, proplist_t *thispanel,
 void
 root_window (const char *conffile, const node *sections,
 	     int sections_restriction_type, bool_t noinet,
-	     GtkWidget *logwindow,  proplist_t *wmc, 
-	     proplist_t *panel, proplist_t *wmlist)
+	     GtkWidget *logwindow,  proplist_t wmc, 
+	     proplist_t panel, proplist_t wmlist)
 /*
  *  Create root window and call the event loop of GTK
  *
@@ -151,17 +152,17 @@ root_window (const char *conffile, const node *sections,
    GtkWidget  *progress_bar    = NULL;
 #endif /* not FREEBSD_SYSTEM */
    GtkWidget  *toolbar;
-   proplist_t *plinfo          = PLMakeString ("Info");
-   proplist_t *pltype          = PLMakeString ("Type");
-   proplist_t *plicon          = PLMakeString ("Icon");
-   proplist_t *pltitle         = PLMakeString ("Title");
-   proplist_t *plwidget        = PLMakeString ("Widget");
-   proplist_t *plcolor         = PLMakeString ("Colorbox");
-   proplist_t *plfont          = PLMakeString ("Fontbox");
-   proplist_t *pltexture       = PLMakeString ("Texturebox");
-   proplist_t *plgrp           = PLMakeString ("Group");
-   proplist_t *plrange         = PLMakeString ("Range");
-   proplist_t *plrinfo         = PLMakeString ("RangeInfo");
+   proplist_t  plinfo          = WMCreatePLString ("Info");
+   proplist_t  pltype          = WMCreatePLString ("Type");
+   proplist_t  plicon          = WMCreatePLString ("Icon");
+   proplist_t  pltitle         = WMCreatePLString ("Title");
+   proplist_t  plwidget        = WMCreatePLString ("Widget");
+   proplist_t  plcolor         = WMCreatePLString ("Colorbox");
+   proplist_t  plfont          = WMCreatePLString ("Fontbox");
+   proplist_t  pltexture       = WMCreatePLString ("Texturebox");
+   proplist_t  plgrp           = WMCreatePLString ("Group");
+   proplist_t  plrange         = WMCreatePLString ("Range");
+   proplist_t  plrinfo         = WMCreatePLString ("RangeInfo");
    GList      *options	       = NULL;
    bool_t      section_found   = NO;
    GtkWidget  *iconbox 	       = gtk_hbox_new (FALSE, 0);
@@ -304,26 +305,26 @@ root_window (const char *conffile, const node *sections,
     *  Section information is extracted from config file 'WMWmakerconf'. 
     */
    {
-      proplist_t *tab = PLGetAllDictionaryKeys (panel);
+      proplist_t tab = WMGetPLDictionaryKeys (panel);
       unsigned	 n;
       
-      for (n = 0; n < PLGetNumberOfElements (tab); n++)
+      for (n = 0; n < WMGetPropListItemCount (tab); n++)
       {
-	 proplist_t *thispanel = PLGetArrayElement (tab, n);
-	 proplist_t *entry     = PLGetDictionaryEntry (panel, thispanel);
-	 proplist_t *info      = PLGetDictionaryEntry (entry, plinfo);
-	 proplist_t *icon      = PLGetDictionaryEntry (entry, plicon);
-	 proplist_t *type      = PLGetDictionaryEntry (entry, pltype);
+	 proplist_t thispanel = WMGetFromPLArray (tab, n);
+	 proplist_t entry     = WMGetFromPLDictionary (panel, thispanel);
+	 proplist_t info      = WMGetFromPLDictionary (entry, plinfo);
+	 proplist_t icon      = WMGetFromPLDictionary (entry, plicon);
+	 proplist_t type      = WMGetFromPLDictionary (entry, pltype);
 	 GtkWidget  *page;
 
-	 if (!icon || !info || !PLIsString (info) || !PLIsString (icon))
+	 if (!icon || !info || !WMIsPLString (info) || !WMIsPLString (icon))
 	    error (_("'%s': parse error."), conffile);
 
 	 /*
 	  *  Check whether the current section is allowed
 	  */
 	 {
-	    char       *thissecname = PLGetString (thispanel);
+	    char       *thissecname = WMGetFromPLString (thispanel);
 	    const node *cur;
 	    bool_t 	matches;
 	    
@@ -343,9 +344,9 @@ root_window (const char *conffile, const node *sections,
 	  *  Create new notbook page (use icon given in WMWmakerconf)
 	  */
 	 {
-	    char *path = g_strconcat (PKGDATADIR, "/", PLGetString (icon), NULL);
+	    char *path = g_strconcat (PKGDATADIR, "/", WMGetFromPLString (icon), NULL);
 	    
-	    page = create_page (GTK_NOTEBOOK (notebook), D_(PLGetString (info)),
+	    page = create_page (GTK_NOTEBOOK (notebook), D_(WMGetFromPLString (info)),
 				path, TRUE);
 	    Free (path);
 	 }
@@ -376,7 +377,7 @@ root_window (const char *conffile, const node *sections,
 	       GtkWidget *image;
 	       GtkWidget *hbox 	= gtk_hbox_new (FALSE, 0);
 	       char 	 *path 	= g_strconcat (PKGDATADIR, "/",
-					       PLGetString (icon), NULL);
+					       WMGetFromPLString (icon), NULL);
 	       
 	       pixmap = gdk_pixmap_create_from_xpm (main_window->window, &mask,
 						    background, path);	       
@@ -392,12 +393,12 @@ root_window (const char *conffile, const node *sections,
 	     *  Config sections (except for Appearance) are
 	     *  surrounded by a frame.
 	     */
-	    if (!strcaseeq (PLGetString (thispanel), "Appearance")
-		&& !strcaseeq (PLGetString (thispanel), "Paths"))
+	    if (!strcaseeq (WMGetFromPLString (thispanel), "Appearance")
+		&& !strcaseeq (WMGetFromPLString (thispanel), "Paths"))
 	    {
 	       GtkWidget *frame;
 
-	       frame = gtk_frame_new (section ? D_(PLGetString (info)) : NULL);
+	       frame = gtk_frame_new (section ? D_(WMGetFromPLString (info)) : NULL);
 	       gtk_frame_set_label_align (GTK_FRAME (frame), 0.5, 0.5);
 	       gtk_frame_set_shadow_type (GTK_FRAME (frame),
 					  GTK_SHADOW_ETCHED_IN);
@@ -417,13 +418,13 @@ root_window (const char *conffile, const node *sections,
 	    /*
 	     *  Generate special containers for Menu, Themes and Appearance
 	     */
-	    if (strcaseeq (PLGetString (thispanel), "Menu") &&
+	    if (strcaseeq (WMGetFromPLString (thispanel), "Menu") &&
 		(!section || strcaseeq (section, "Menu")))
 	       box = rootmenu_dialog (box, tooltips);
-	    if (strcaseeq (PLGetString (thispanel), "Themes") &&
+	    if (strcaseeq (WMGetFromPLString (thispanel), "Themes") &&
 		(!section || strcaseeq (section, "Themes")))
 	       box = theme_browser (box, section != NULL);
-	    if (strcaseeq (PLGetString (thispanel), "Appearance") &&
+	    if (strcaseeq (WMGetFromPLString (thispanel), "Appearance") &&
 		(!section || strcaseeq (section, "Appearance")))
 	       appearance_container (type, thispanel, &options, box);
 
@@ -431,14 +432,14 @@ root_window (const char *conffile, const node *sections,
 	     *  Store container widget of current panel
 	     */
 	    {
-	       proplist_t *data;
-	       data = PLMakeData ((unsigned char *) &box, sizeof (GtkWidget *));
-	       PLInsertDictionaryEntry (entry, plwidget, data);
-	       PLRelease (data);
+	       proplist_t data;
+	       data = WMCreatePLDataWithBytes ((unsigned char *) &box, sizeof (GtkWidget *));
+	       WMPutInPLDictionary (entry, plwidget, data);
+	       WMReleasePropList (data);
 	    }
 	 }
       }
-      PLRelease (tab);
+      WMReleasePropList (tab);
    }
 
    if (!section_found)
@@ -451,27 +452,27 @@ root_window (const char *conffile, const node *sections,
     *  Add config widget for each defined Window Maker attribute
     */
    {
-      proplist_t *all_keys = PLGetAllDictionaryKeys (wmconfig);
-      unsigned   melem     = PLGetNumberOfElements (all_keys);
+      proplist_t all_keys = WMGetPLDictionaryKeys (wmconfig);
+      unsigned   melem     = WMGetPropListItemCount (all_keys);
       unsigned	 n;
 
       for (n = 0; n < melem; n++)
       {
-	 proplist_t *key    = PLGetArrayElement (all_keys, n);
-	 proplist_t *value  = PLGetDictionaryEntry (windowmaker, key);
-	 proplist_t *keydef = PLGetDictionaryEntry (wmconfig, key);
-	 proplist_t *group  = PLGetDictionaryEntry (keydef, plgrp);
-	 proplist_t *title  = PLGetDictionaryEntry (keydef, pltitle);
-	 proplist_t *range;
-	 proplist_t *info;
-	 proplist_t *rinfo;
+	 proplist_t key    = WMGetFromPLArray (all_keys, n);
+	 proplist_t value  = WMGetFromPLDictionary (windowmaker, key);
+	 proplist_t keydef = WMGetFromPLDictionary (wmconfig, key);
+	 proplist_t group  = WMGetFromPLDictionary (keydef, plgrp);
+	 proplist_t title  = WMGetFromPLDictionary (keydef, pltitle);
+	 proplist_t range;
+	 proplist_t info;
+	 proplist_t rinfo;
 	 GtkWidget  *page_box;
 	 char	    *name;
 	 char	    *type;
-	 proplist_t *ptype;
-	 proplist_t *pentry;
+	 proplist_t ptype;
+	 proplist_t pentry;
 	 
-	 if (strcaseeq (PLGetString (group), "None"))
+	 if (strcaseeq (WMGetFromPLString (group), "None"))
 	    continue;
 	 
 #ifndef FREEBSD_SYSTEM   
@@ -480,7 +481,7 @@ root_window (const char *conffile, const node *sections,
 	  */
 	 if (!section)
 	 {
-	    gtk_label_set_text (GTK_LABEL (progress_label), PLGetString (key));
+	    gtk_label_set_text (GTK_LABEL (progress_label), WMGetFromPLString (key));
 	    gtk_progress_bar_update (GTK_PROGRESS_BAR (progress_bar),
 				     n / (double) melem);
 	    gtk_widget_draw (progress_window, NULL);
@@ -490,17 +491,17 @@ root_window (const char *conffile, const node *sections,
 	 while (gtk_events_pending())
 	    gtk_main_iteration();
 
-	 range = PLGetDictionaryEntry (keydef, plrange);
-	 rinfo = PLGetDictionaryEntry (keydef, plrinfo);
-	 info  = PLGetDictionaryEntry (keydef, plinfo);
-	 name  = PLGetString (key);
-	 type  = PLGetString (PLGetDictionaryEntry (keydef, pltype));
+	 range = WMGetFromPLDictionary (keydef, plrange);
+	 rinfo = WMGetFromPLDictionary (keydef, plrinfo);
+	 info  = WMGetFromPLDictionary (keydef, plinfo);
+	 name  = WMGetFromPLString (key);
+	 type  = WMGetFromPLString (WMGetFromPLDictionary (keydef, pltype));
 
 	 /*
 	  *  We need attributes of actived sections only
 	  */
 	 {
-	    char        *thissecname = PLGetString (group);
+	    char        *thissecname = WMGetFromPLString (group);
 	    const node*  cur;
 	    bool_t 	 matches;
 	    
@@ -521,60 +522,60 @@ root_window (const char *conffile, const node *sections,
 	  */
 	 {
 	    char	*pos;
-	    proplist_t	*pgroup;
-	    proplist_t  *pbox;
-	    char	*groupname = g_strdup (PLGetString (group));
+	    proplist_t	pgroup;
+	    proplist_t  pbox;
+	    char	*groupname = g_strdup (WMGetFromPLString (group));
 
 	    if ((pos = strchr (groupname, '/')))
 	       *pos = 0;
 	    
-	    pgroup = PLMakeString (groupname);
-	    pentry = PLGetDictionaryEntry (panel, pgroup);
-	    pbox   = PLGetDictionaryEntry (pentry, plwidget);
-	    ptype  = PLGetDictionaryEntry (pentry, pltype);
-	    PLRelease (pgroup);
+	    pgroup = WMCreatePLString (groupname);
+	    pentry = WMGetFromPLDictionary (panel, pgroup);
+	    pbox   = WMGetFromPLDictionary (pentry, plwidget);
+	    ptype  = WMGetFromPLDictionary (pentry, pltype);
+	    WMReleasePropList (pgroup);
 	    
 	    if (!pentry || !pbox || !ptype)
 	       continue;
 
-	    if (PLIsDictionary (ptype)) /* get sub entry */
+	    if (WMIsPLDictionary (ptype)) /* get sub entry */
 	    {
 	       char *subname = pos + 1;
 
 	       if ((pos = strchr (subname, '/')))
 		  *pos = 0;
 	       
-	       pgroup = PLMakeString (subname);
-	       pentry = PLGetDictionaryEntry (ptype, pgroup); 
-	       ptype  = PLGetDictionaryEntry (pentry, pltype);
-	       PLRelease (pgroup);
+	       pgroup = WMCreatePLString (subname);
+	       pentry = WMGetFromPLDictionary (ptype, pgroup); 
+	       ptype  = WMGetFromPLDictionary (pentry, pltype);
+	       WMReleasePropList (pgroup);
 
-	       if (PLIsDictionary (ptype) && pos) /* get sub sub entry */
+	       if (WMIsPLDictionary (ptype) && pos) /* get sub sub entry */
 	       {
-		  pgroup = PLMakeString (pos + 1);
-		  pentry = PLGetDictionaryEntry (ptype, pgroup);
-		  PLRelease (pgroup);
+		  pgroup = WMCreatePLString (pos + 1);
+		  pentry = WMGetFromPLDictionary (ptype, pgroup);
+		  WMReleasePropList (pgroup);
 		  if (strcaseeq (type, "Color") || strcaseeq (type, "TextColor") )
-		     pbox = PLGetDictionaryEntry (pentry, plcolor);
+		     pbox = WMGetFromPLDictionary (pentry, plcolor);
 		  else if (strcaseeq (type, "Font"))
-		     pbox = PLGetDictionaryEntry (pentry, plfont);
+		     pbox = WMGetFromPLDictionary (pentry, plfont);
 		  else if (strcaseeq (type, "Texture"))
-		     pbox = PLGetDictionaryEntry (pentry, pltexture);
+		     pbox = WMGetFromPLDictionary (pentry, pltexture);
 		  else
-		     pbox = PLGetDictionaryEntry (pentry, plwidget);
+		     pbox = WMGetFromPLDictionary (pentry, plwidget);
 	       }
 	       else
 	       {
 		  if (strcaseeq (type, "Color") || strcaseeq (type, "TextColor"))
-		     pbox = PLGetDictionaryEntry (pentry, plcolor);
+		     pbox = WMGetFromPLDictionary (pentry, plcolor);
 		  else if (strcaseeq (type, "Font"))
-		     pbox = PLGetDictionaryEntry (pentry, plfont);
+		     pbox = WMGetFromPLDictionary (pentry, plfont);
 		  else if (strcaseeq (type, "Texture"))
-		     pbox = PLGetDictionaryEntry (pentry, pltexture);
+		     pbox = WMGetFromPLDictionary (pentry, pltexture);
 		  else
-		     pbox = PLGetDictionaryEntry (pentry, plwidget);
+		     pbox = WMGetFromPLDictionary (pentry, plwidget);
 	       }
-	       page_box = * (GtkWidget **) PLGetDataBytes (pbox);
+	       page_box = * (GtkWidget **) WMGetPLDataBytes (pbox);
 	       {
 		  GtkWidget *frame;
 		  frame = gtk_object_get_user_data (GTK_OBJECT (page_box));
@@ -585,7 +586,7 @@ root_window (const char *conffile, const node *sections,
 	       }
 	    }
 	    else
-	       page_box = * (GtkWidget **) PLGetDataBytes (pbox);
+	       page_box = * (GtkWidget **) WMGetPLDataBytes (pbox);
 
 	    Free (groupname);
 	 }
@@ -605,7 +606,7 @@ root_window (const char *conffile, const node *sections,
 	    iboolean_dialog (page_box, key, value, title);
 	 }
 	 else if (strcaseeq ("String", type)
-		  && !strcaseeq ("ModifierKey", PLGetString (key)))
+		  && !strcaseeq ("ModifierKey", WMGetFromPLString (key)))
 	 {
 	    string_dialog (page_box, key, value, range, rinfo, title);
 	 }
@@ -622,17 +623,17 @@ root_window (const char *conffile, const node *sections,
 		  || strcaseeq ("Texture", type)) 
 	 {
 	    GtkWidget	*widget;
-	    proplist_t	*data;
+	    proplist_t	data;
 
 	    if (strcaseeq ("Font", type)) 
 	       widget = font_dialog (page_box, key, value, info);
 	    else if (strcaseeq ("Texture", type))
 	    {
 	       GtkWidget  *box     = NULL;
-	       proplist_t *fontbox = PLGetDictionaryEntry (pentry, plfont);
+	       proplist_t fontbox = WMGetFromPLDictionary (pentry, plfont);
 
 	       if (fontbox)
-		  box = * (GtkWidget **) PLGetDataBytes (fontbox);
+		  box = * (GtkWidget **) WMGetPLDataBytes (fontbox);
 	       widget = texture_dialog (page_box, box, key);
 	    }
 #ifdef HAVE_LIBWMFUN
@@ -644,11 +645,11 @@ root_window (const char *conffile, const node *sections,
 	       widget = color_dialog (page_box, key, value, tooltips,
 				      info, title);
 
-	    data = PLMakeData ((unsigned char *) &widget, sizeof (GtkWidget *));
-	    PLInsertDictionaryEntry (keydef, plwidget, data);
-	    PLRelease (data);
+	    data = WMCreatePLDataWithBytes ((unsigned char *) &widget, sizeof (GtkWidget *));
+	    WMPutInPLDictionary (keydef, plwidget, data);
+	    WMReleasePropList (data);
 
-	    if (PLIsDictionary (ptype)) /* subsubbox */
+	    if (WMIsPLDictionary (ptype)) /* subsubbox */
 	       gtk_widget_hide (widget);
 	 }
 	 else if (strcaseeq ("Key", type)) 
@@ -657,11 +658,11 @@ root_window (const char *conffile, const node *sections,
 	 }
 	 else if (strcaseeq ("Pathlist", type))
 	 {
-	    if (!streq (PLGetString (key), "ThemePath"))
+	    if (!streq (WMGetFromPLString (key), "ThemePath"))
 	       path_dialog (page_box, key, value, tooltips, info);
 	 }
       }
-      PLRelease (all_keys);
+      WMReleasePropList (all_keys);
    }
    
    gtk_widget_set_usize (main_window,
@@ -678,16 +679,16 @@ root_window (const char *conffile, const node *sections,
       gtk_widget_destroy (progress_window);
 #endif /* not FREEBSD_SYSTEM */
 
-   PLRelease (plinfo);
-   PLRelease (pltype);
-   PLRelease (plicon);
-   PLRelease (plwidget);
-   PLRelease (plcolor);
-   PLRelease (plfont);
-   PLRelease (pltexture);
-   PLRelease (plrange);
-   PLRelease (plgrp);
-   PLRelease (pltitle);
+   WMReleasePropList (plinfo);
+   WMReleasePropList (pltype);
+   WMReleasePropList (plicon);
+   WMReleasePropList (plwidget);
+   WMReleasePropList (plcolor);
+   WMReleasePropList (plfont);
+   WMReleasePropList (pltexture);
+   WMReleasePropList (plrange);
+   WMReleasePropList (plgrp);
+   WMReleasePropList (pltitle);
 
    g_list_foreach (options, init_option_menu, NULL);
    g_list_free (options);
@@ -732,13 +733,13 @@ root_window (const char *conffile, const node *sections,
 void
 check_widgetstyle (void)
 {
-   proplist_t *plnewstyle = PLMakeString ("NewStyle");
-   proplist_t *value	  = PLGetDictionaryEntry (windowmaker, plnewstyle);
+   proplist_t plnewstyle = WMCreatePLString ("NewStyle");
+   proplist_t value	  = WMGetFromPLDictionary (windowmaker, plnewstyle);
 
    if (widgetstyle_item)
       gtk_widget_set_sensitive (widgetstyle_item, !convert_bool (value));
    
-   PLRelease (plnewstyle);
+   WMReleasePropList (plnewstyle);
 }
 
 char *
@@ -774,15 +775,15 @@ get_pixmap_path (const char *name)
    {
       unsigned	 n;
       char	 *found	      = NULL;
-      proplist_t *plpath      = PLMakeString ("PixmapPath");
-      proplist_t *pixmap_path = PLGetDictionaryEntry (windowmaker, plpath);
+      proplist_t plpath      = WMCreatePLString ("PixmapPath");
+      proplist_t pixmap_path = WMGetFromPLDictionary (windowmaker, plpath);
       
-      PLRelease (plpath);
+      WMReleasePropList (plpath);
 
-      for (n = 0; n < PLGetNumberOfElements (pixmap_path) && !found; n++)
+      for (n = 0; n < WMGetPropListItemCount (pixmap_path) && !found; n++)
       {
 	 FILE *file;
-	 char *path = expand_tilde (PLGetString (PLGetArrayElement (pixmap_path,
+	 char *path = expand_tilde (WMGetFromPLString (WMGetFromPLArray (pixmap_path,
 								    n)));
 	 char *filename = g_strconcat (path, "/", name, NULL);
 
@@ -1020,43 +1021,42 @@ save_config_file (GtkWidget *widget, gpointer ptr)
    
    if (changed)
    {
-      proplist_t *newwm = PLMakeDictionaryFromEntries (NULL, NULL, NULL);
+      proplist_t newwm = WMCreatePLDictionary (NULL, NULL, NULL);
       
-      PLSetFilename (newwm, PLRetain (PLGetFilename (windowmaker)));
       /*
        *  Compare user attributes with system attributes
        */
       {
-	 proplist_t *all_keys = PLGetAllDictionaryKeys (windowmaker) ;
+	 proplist_t all_keys = WMGetPLDictionaryKeys (windowmaker) ;
 	 unsigned	 n;
       
-	 for (n = 0; n < PLGetNumberOfElements (all_keys); n++)
+	 for (n = 0; n < WMGetPropListItemCount (all_keys); n++)
 	 {
-	    proplist_t *user;
-	    proplist_t *key = PLGetArrayElement (all_keys, n);
+	    proplist_t user;
+	    proplist_t key = WMGetFromPLArray (all_keys, n);
 	 
-	    user = PLGetDictionaryEntry (windowmaker, key);
+	    user = WMGetFromPLDictionary (windowmaker, key);
 
-	    if (PLGetDictionaryEntry (plist_changed, key))
-	       PLInsertDictionaryEntry (newwm, key, PLDeepCopy (user));
+	    if (WMGetFromPLDictionary (plist_changed, key))
+	       WMPutInPLDictionary (newwm, key, WMDeepCopyPropList (user));
 	 }
-	 PLRelease (all_keys);
+	 WMReleasePropList (all_keys);
       }
 
-      if (PLSave (newwm, YES))
+      if (WMWritePropListToFile (newwm, orig_wmaker_fname, YES))
       {
 	 changed = NO;
 	 message (_("Window Maker config file '%s' saved."),
-		  PLGetString (PLGetFilename (newwm)));
+		  orig_wmaker_fname);
       }
       else
       {
 	 dialog_popup (DIALOG_ERROR, NULL, NULL,
 		       _("Can't write to Window Maker file\n`%s'."),
-		       PLGetString (PLGetFilename (newwm)));
+		       orig_wmaker_fname);
 	 return;
       }
-      PLRelease (newwm);
+      WMReleasePropList (newwm);
    }
 
    enable_revert ();
@@ -1073,21 +1073,21 @@ save_config_file (GtkWidget *widget, gpointer ptr)
 *****************************************************************************/
 
 static void
-appearance_container (proplist_t *type, proplist_t *thispanel,
+appearance_container (proplist_t type, proplist_t thispanel,
 		      GList **options, GtkWidget *box)
 /*
  *  Gererate sub-containers for each appearance sub-panel.
  */
 {
-   proplist_t *subentries = PLGetAllDictionaryKeys (type);
+   proplist_t  subentries = WMGetPLDictionaryKeys (type);
    GtkWidget  *subbook    = gtk_notebook_new ();
-   proplist_t *plinfo     = PLMakeString ("Info");
-   proplist_t *plfont     = PLMakeString ("Fontbox");
-   proplist_t *pltexture  = PLMakeString ("Texturebox");
-   proplist_t *plcolor    = PLMakeString ("Colorbox");
-   proplist_t *plwidget   = PLMakeString ("Widget");
-   proplist_t *pltype     = PLMakeString ("Type");
-   proplist_t *plicon     = PLMakeString ("Icon");
+   proplist_t  plinfo     = WMCreatePLString ("Info");
+   proplist_t  plfont     = WMCreatePLString ("Fontbox");
+   proplist_t  pltexture  = WMCreatePLString ("Texturebox");
+   proplist_t  plcolor    = WMCreatePLString ("Colorbox");
+   proplist_t  plwidget   = WMCreatePLString ("Widget");
+   proplist_t  pltype     = WMCreatePLString ("Type");
+   proplist_t  plicon     = WMCreatePLString ("Icon");
    unsigned    i;
 	       
    gtk_notebook_set_show_tabs (GTK_NOTEBOOK (subbook), TRUE);
@@ -1101,31 +1101,31 @@ appearance_container (proplist_t *type, proplist_t *thispanel,
    while (gtk_events_pending())
       gtk_main_iteration();
 	       
-   for (i = 0; i < PLGetNumberOfElements (subentries); i++)
+   for (i = 0; i < WMGetPropListItemCount (subentries); i++)
    {
       GtkWidget  *subpage;
-      proplist_t *thissub  = PLGetArrayElement (subentries, i);
-      proplist_t *subentry = PLGetDictionaryEntry (type, thissub);
-      proplist_t *subinfo  = PLGetDictionaryEntry (subentry, plinfo);
-      proplist_t *subicon  = PLGetDictionaryEntry (subentry, plicon);
-      proplist_t *subtype  = PLGetDictionaryEntry (subentry, pltype);
+      proplist_t  thissub  = WMGetFromPLArray (subentries, i);
+      proplist_t  subentry = WMGetFromPLDictionary (type, thissub);
+      proplist_t  subinfo  = WMGetFromPLDictionary (subentry, plinfo);
+      proplist_t  subicon  = WMGetFromPLDictionary (subentry, plicon);
+      proplist_t  subtype  = WMGetFromPLDictionary (subentry, pltype);
       char 	 *path     = NULL;
 		  
-      if (subicon && PLIsString (subicon)) /* subsubsections ? */
+      if (subicon && WMIsPLString (subicon)) /* subsubsections ? */
 	 path = g_strconcat (PKGDATADIR, "/",
-			     PLGetString (subicon), NULL);
+			     WMGetFromPLString (subicon), NULL);
       subpage = create_page (GTK_NOTEBOOK (subbook),
-			     D_(PLGetString (subinfo)), path, FALSE);
+			     D_(WMGetFromPLString (subinfo)), path, FALSE);
       if (path)
 	 Free (path);
 
       {
-	 proplist_t *data;
+	 proplist_t data;
 		     
-	 data = PLMakeData ((unsigned char *) &subpage,
+	 data = WMCreatePLDataWithBytes ((unsigned char *) &subpage,
 			    sizeof (GtkWidget *));
-	 PLInsertDictionaryEntry (subentry, plwidget, data);
-	 PLRelease (data);
+	 WMPutInPLDictionary (subentry, plwidget, data);
+	 WMReleasePropList (data);
       }
 		  
 		  
@@ -1143,9 +1143,9 @@ appearance_container (proplist_t *type, proplist_t *thispanel,
 	 GtkWidget  *color_box     = gtk_hbox_new (FALSE, 0);
 	 GtkWidget  *texture_box   = gtk_vbox_new (FALSE, 0);
 	 GtkWidget  *hbox;
-	 proplist_t *color_data;
-	 proplist_t *texture_data;
-	 proplist_t *font_data;
+	 proplist_t color_data;
+	 proplist_t texture_data;
+	 proplist_t font_data;
 		     
 	 gtk_container_add (GTK_CONTAINER (subpage), vbox);
 		     
@@ -1177,7 +1177,7 @@ appearance_container (proplist_t *type, proplist_t *thispanel,
 	    gtk_frame_set_label_align (GTK_FRAME (frame), 0.5, 0.5);
 	    gtk_container_add (GTK_CONTAINER (frame), box);
 	    gtk_container_set_border_width (GTK_CONTAINER (box), 5);
-	    color_data = PLMakeData ((unsigned char *) &box,
+	    color_data = WMCreatePLDataWithBytes ((unsigned char *) &box,
 				     sizeof (GtkWidget *));
 	    gtk_object_set_user_data (GTK_OBJECT (box),
 				      color_frame);
@@ -1195,7 +1195,7 @@ appearance_container (proplist_t *type, proplist_t *thispanel,
 				TRUE, TRUE, 0);
 	    gtk_frame_set_label_align (GTK_FRAME (frame), 0.5, 0.5);
 	    gtk_container_add (GTK_CONTAINER (frame), box);
-	    texture_data = PLMakeData ((unsigned char *) &box,
+	    texture_data = WMCreatePLDataWithBytes ((unsigned char *) &box,
 				       sizeof (GtkWidget *));
 	    gtk_object_set_user_data (GTK_OBJECT (box),
 				      texture_frame);
@@ -1204,7 +1204,7 @@ appearance_container (proplist_t *type, proplist_t *thispanel,
 	  *  Font box
 	  */
 	 {
-	    font_data = PLMakeData ((unsigned char *) &nw_hbox,
+	    font_data = WMCreatePLDataWithBytes ((unsigned char *) &nw_hbox,
 				    sizeof (GtkWidget *));
 	 }
 	 gtk_widget_show_all (subpage);
@@ -1218,43 +1218,43 @@ appearance_container (proplist_t *type, proplist_t *thispanel,
 	  *  Make option box with subsubsections and subboxes
 	  *  for color, texture and font
 	  */
-	 if (subtype && PLIsDictionary (subtype))
+	 if (subtype && WMIsPLDictionary (subtype))
 	 {
-	    proplist_t *ssentries = PLGetAllDictionaryKeys (subtype);
+	    proplist_t ssentries = WMGetPLDictionaryKeys (subtype);
 	    unsigned   k;
 	    char	   *path;
 	    GtkWidget  *option_menu = gtk_option_menu_new ();
 	    GtkWidget  *menu        = gtk_menu_new ();
 
-	    path = g_strconcat (PLGetString (thispanel), "/",
-				PLGetString (thissub), NULL);
+	    path = g_strconcat (WMGetFromPLString (thispanel), "/",
+				WMGetFromPLString (thissub), NULL);
 
-	    for (k = 0; k < PLGetNumberOfElements (ssentries); k++)
+	    for (k = 0; k < WMGetPropListItemCount (ssentries); k++)
 	    {
-	       proplist_t *thisss;
-	       proplist_t *ssentry;
-	       proplist_t *ssinfo;
+	       proplist_t thisss;
+	       proplist_t ssentry;
+	       proplist_t ssinfo;
 	       GtkWidget  *menu_item;
 			   
-	       thisss    = PLGetArrayElement (ssentries, k);
-	       ssentry   = PLGetDictionaryEntry (subtype, thisss);
-	       ssinfo    = PLGetDictionaryEntry (ssentry, plinfo);
-	       menu_item = gtk_menu_item_new_with_label (D_(PLGetString (ssinfo)));
+	       thisss    = WMGetFromPLArray (ssentries, k);
+	       ssentry   = WMGetFromPLDictionary (subtype, thisss);
+	       ssinfo    = WMGetFromPLDictionary (ssentry, plinfo);
+	       menu_item = gtk_menu_item_new_with_label (D_(WMGetFromPLString (ssinfo)));
 	       gtk_signal_connect (GTK_OBJECT (menu_item), "activate",
 				   GTK_SIGNAL_FUNC (switch_subentries),
 				   path);
 	       gtk_object_set_user_data (GTK_OBJECT (menu_item),
-					 (gpointer) PLGetString (thisss));
+					 (gpointer) WMGetFromPLString (thisss));
 	       gtk_menu_append (GTK_MENU (menu), menu_item);
 	       gtk_widget_show (menu_item);
 
-	       PLInsertDictionaryEntry (ssentry, plcolor,
+	       WMPutInPLDictionary (ssentry, plcolor,
 					color_data);
-	       PLInsertDictionaryEntry (ssentry, pltexture,
+	       WMPutInPLDictionary (ssentry, pltexture,
 					texture_data);
-	       PLInsertDictionaryEntry (ssentry, plfont,
+	       WMPutInPLDictionary (ssentry, plfont,
 					font_data);
-	       if (strcaseeq (PLGetString (thisss), "Widget"))
+	       if (strcaseeq (WMGetFromPLString (thisss), "Widget"))
 		  widgetstyle_item = menu_item;
 	    }
 	    gtk_option_menu_set_menu (GTK_OPTION_MENU (option_menu),
@@ -1270,7 +1270,7 @@ appearance_container (proplist_t *type, proplist_t *thispanel,
 	       GtkWidget *frame;
 	       GtkWidget *box = gtk_hbox_new (TRUE, 0);
 
-	       frame = gtk_frame_new (D_(PLGetString (subinfo)));
+	       frame = gtk_frame_new (D_(WMGetFromPLString (subinfo)));
 	       gtk_frame_set_label_align (GTK_FRAME (frame),
 					  0.5, 0.5);
 	       gtk_container_set_border_width (GTK_CONTAINER (box), 5);
@@ -1288,26 +1288,26 @@ appearance_container (proplist_t *type, proplist_t *thispanel,
 	 }
 	 else
 	 {
-	    PLInsertDictionaryEntry (subentry, plcolor,
+	    WMPutInPLDictionary (subentry, plcolor,
 				     color_data);
-	    PLInsertDictionaryEntry (subentry, pltexture,
+	    WMPutInPLDictionary (subentry, pltexture,
 				     texture_data);
-	    PLInsertDictionaryEntry (subentry, plfont,
+	    WMPutInPLDictionary (subentry, plfont,
 				     font_data);
 	 }
-	 PLRelease (color_data);
-	 PLRelease (texture_data);
-	 PLRelease (font_data);
+	 WMReleasePropList (color_data);
+	 WMReleasePropList (texture_data);
+	 WMReleasePropList (font_data);
       }
    }
-   PLRelease (subentries);
-   PLRelease (plinfo);
-   PLRelease (pltype);
-   PLRelease (plicon);
-   PLRelease (plwidget);
-   PLRelease (plcolor);
-   PLRelease (plfont);
-   PLRelease (pltexture);
+   WMReleasePropList (subentries);
+   WMReleasePropList (plinfo);
+   WMReleasePropList (pltype);
+   WMReleasePropList (plicon);
+   WMReleasePropList (plwidget);
+   WMReleasePropList (plcolor);
+   WMReleasePropList (plfont);
+   WMReleasePropList (pltexture);
 }
 
 static void
@@ -1376,25 +1376,25 @@ switch_subentries (GtkWidget *widget, gpointer ptr)
  */
 {
    unsigned	n;
-   proplist_t	*all_keys = PLGetAllDictionaryKeys (wmconfig);
-   proplist_t	*plgrp    = PLMakeString ("Group");
-   proplist_t	*plwidget = PLMakeString ("Widget");
+   proplist_t	 all_keys = WMGetPLDictionaryKeys (wmconfig);
+   proplist_t	 plgrp    = WMCreatePLString ("Group");
+   proplist_t	 plwidget = WMCreatePLString ("Widget");
    char         *text     = gtk_object_get_user_data (GTK_OBJECT (widget));
    char         *prefix   = (char *) ptr;
    char		*path	  = g_strconcat (prefix, "/", text, NULL);
    
-   for (n = 0; n < PLGetNumberOfElements (all_keys); n++)
+   for (n = 0; n < WMGetPropListItemCount (all_keys); n++)
    {
-      proplist_t *key    = PLGetArrayElement (all_keys, n);
-      proplist_t *keydef = PLGetDictionaryEntry (wmconfig, key);
-      proplist_t *data   = PLGetDictionaryEntry (keydef, plwidget);
+      proplist_t key    = WMGetFromPLArray (all_keys, n);
+      proplist_t keydef = WMGetFromPLDictionary (wmconfig, key);
+      proplist_t data   = WMGetFromPLDictionary (keydef, plwidget);
 
       if (data)
       {
-	 proplist_t *group = PLGetDictionaryEntry (keydef, plgrp);
-	 GtkWidget  *widget = * (GtkWidget **) PLGetDataBytes (data);
+	 proplist_t group = WMGetFromPLDictionary (keydef, plgrp);
+	 GtkWidget  *widget = * (GtkWidget **) WMGetPLDataBytes (data);
 
-	 if (strcaseeq (path, PLGetString (group)))
+	 if (strcaseeq (path, WMGetFromPLString (group)))
 	    gtk_widget_show (widget);
 	 else
 	 {
@@ -1403,7 +1403,7 @@ switch_subentries (GtkWidget *widget, gpointer ptr)
 	    /*  g_strncasecmp: only in GTK+1.1.x */
 	    {
 	       char *str1 = g_strdup (path);
-	       char *str2 = g_strdup (PLGetString (group));
+	       char *str2 = g_strdup (WMGetFromPLString (group));
 
 	       str1 [right - path] = 0;
 	       str2 [right - path] = 0;
@@ -1416,7 +1416,7 @@ switch_subentries (GtkWidget *widget, gpointer ptr)
 	 }
       }
    }
-   PLRelease (plwidget);
-   PLRelease (plgrp);
+   WMReleasePropList (plwidget);
+   WMReleasePropList (plgrp);
 }
 
