@@ -41,7 +41,8 @@
 #	include <locale.h>
 #endif
 
-#include <proplist.h>
+#include "proplist_t.h"
+
 #include <gtk/gtk.h>
 #include <stdio.h>
 
@@ -57,15 +58,15 @@
   
 *******************************************************************************/
 
-char	   *wmpath        = NULL;	/* path to WindowMaker attributes file */
-proplist_t *plist_changed = NULL;	/* modified proplist keys */
-proplist_t *pl_yes        = NULL;	/* dummy */
-proplist_t *orig_wmaker   = NULL;	/* original WindowMaker file */
-proplist_t *orig_rootmenu = NULL;	/* original WMRootMenu file */
+proplist_t plist_changed 	= NULL;	/* modified proplist keys */
+proplist_t pl_yes        	= NULL;	/* dummy */
+proplist_t orig_wmaker   	= NULL;	/* original WindowMaker file */
+char       *orig_wmaker_fname 	= NULL;	/* original WindowMaker filename */
+proplist_t orig_rootmenu 	= NULL;	/* original WMRootMenu file */
+char       *orig_rootmenu_fname = NULL;	/* original WMRootMenu filename */
+ 
 GtkWidget  *log_text      = NULL;
 
-static BOOL
-StringCompareHook (proplist_t pl1, proplist_t pl2);
 static GtkWidget *
 make_log_window (void);
 static void
@@ -81,11 +82,11 @@ usage(int status);
 int
 main (int argc, char **argv)
 {
-   proplist_t *global_windowmaker;	/* global defined options */
-   proplist_t *windowmaker;		/* user defined options in WindowMaker */
-   proplist_t *wmconfig;		/* WindowMaker attributes */
-   proplist_t *wmpanel;			/* Panel */
-   proplist_t *wmakerconf;
+   proplist_t global_windowmaker;	/* global defined options */
+   proplist_t windowmaker;		/* user defined options in WindowMaker */
+   proplist_t wmconfig;			/* WindowMaker attributes */
+   proplist_t wmpanel;			/* Panel */
+   proplist_t wmakerconf;
    GtkWidget  *window;
    const char *conffile 		 = PKGDATADIR "/WMWmakerconf";   
    bool_t      no_inet 			 = NO;
@@ -93,7 +94,8 @@ main (int argc, char **argv)
    int	       sections_restriction_type = -1;
    node	      *sections 		 = NULL;	
    
-   PLSetStringCmpHook (StringCompareHook);
+   WMPLSetCaseSensitive(FALSE);
+   
    
    gtk_set_locale ();
    gtk_init (&argc, &argv);
@@ -179,74 +181,66 @@ main (int argc, char **argv)
     *  Read control file of wmakerconf
     */
    {
-      proplist_t *plpanel  = PLMakeString ("Panel");
-      proplist_t *plwmaker = PLMakeString ("WindowMaker");
+      proplist_t plpanel  = WMCreatePLString ("Panel");
+      proplist_t plwmaker = WMCreatePLString ("WindowMaker");
       
       wmakerconf = read_proplist (conffile);
       if (!wmakerconf)
 	 error (_("Can't read file '%s'"), conffile);
       
-      wmconfig = PLGetDictionaryEntry (wmakerconf, plwmaker);
+      wmconfig = WMGetFromPLDictionary (wmakerconf, plwmaker);
       if (!wmconfig)
 	 error (_("'%s': parse error."), conffile);
 
-      wmpanel = PLGetDictionaryEntry (wmakerconf, plpanel);
+      wmpanel = WMGetFromPLDictionary (wmakerconf, plpanel);
       if (!wmpanel)
 	 error (_("'%s': parse error."), conffile);
 
-      PLRelease (plpanel);
-      PLRelease (plwmaker);
+      WMReleasePropList (plpanel);
+      WMReleasePropList (plwmaker);
    }
    
    /*
     *  Read 'WMRootMenu' file
     */
    {
-      char *text = get_gnustep_path ("Defaults/WMRootMenu");
-
-      orig_rootmenu = read_proplist (text);
+      orig_rootmenu_fname = get_gnustep_path ("Defaults/WMRootMenu");
+      orig_rootmenu = read_proplist (orig_rootmenu_fname);
       if (orig_rootmenu)
       {
-	 char		*new   = g_strconcat (text, ".bak", NULL);
-	 proplist_t	*porig = PLGetFilename (orig_rootmenu);
-	 proplist_t	*pnew  = PLMakeString (new);
+	 char *new = g_strconcat (orig_rootmenu_fname, ".bak", NULL);
 	 
 	 /*
 	  *  Generate backup file "'path'.bak"
 	  */
-	 PLSetFilename (orig_rootmenu, pnew);
-	 if (PLSave (orig_rootmenu, YES))
+	 if (WMWritePropListToFile (orig_rootmenu, new, YES))
 	    message (_("Backupfile `%s' generated."), new);
 	 else
 	    error (_("Can't write backupfile `%s'."), new);
-	 PLSetFilename (orig_rootmenu, porig);
-	 PLRelease (pnew);
 	 Free (new);
       }
-      Free (text);
    }
    
    /*
     *  Open 'WindowMaker' file
     */
-   if (!wmpath)
-      wmpath = get_gnustep_path ("Defaults/WindowMaker");
-   windowmaker = read_proplist (wmpath);
+   orig_wmaker_fname = get_gnustep_path ("Defaults/WindowMaker");
+   windowmaker = read_proplist (orig_wmaker_fname);
 
-   plist_changed = PLMakeDictionaryFromEntries (NULL, NULL, NULL);
-   pl_yes	 = PLMakeString ("Yes");
+   plist_changed = WMCreatePLDictionary (NULL, NULL, NULL);
+   pl_yes	 = WMCreatePLString ("Yes");
    
-   if (windowmaker && PLIsDictionary (windowmaker))
+   if (windowmaker && WMIsPLDictionary (windowmaker))
    {
-      proplist_t *keys  = PLGetAllDictionaryKeys (windowmaker);
+      proplist_t keys  = WMGetPLDictionaryKeys (windowmaker);
       unsigned	 n;
       
-      for (n = 0; n < PLGetNumberOfElements (keys); n++)
-	 PLInsertDictionaryEntry (plist_changed, PLGetArrayElement (keys, n),
+      for (n = 0; n < WMGetPropListItemCount (keys); n++)
+	 WMPutInPLDictionary (plist_changed, WMGetFromPLArray (keys, n),
 				  pl_yes);
 
-      PLRelease (keys);
-      orig_wmaker = PLDeepCopy (windowmaker);
+      WMReleasePropList (keys);
+      orig_wmaker = WMDeepCopyPropList (windowmaker);
    }
    
    /*
@@ -277,95 +271,80 @@ main (int argc, char **argv)
    if (!global_windowmaker)
    {
       warning (_("Can't open global WindowMaker configuration file."));
-      global_windowmaker = PLMakeDictionaryFromEntries (NULL, NULL, NULL);
+      global_windowmaker = WMCreatePLDictionary (NULL, NULL, NULL);
    }
    
    if (!windowmaker)
    {
       windowmaker = global_windowmaker;
-      PLSetFilename (windowmaker, PLMakeString (wmpath));
-      if (PLSave (windowmaker, YES))
-	 warning (_("New WindowMaker configuration file `%s' created."), wmpath);
+      if (WMWritePropListToFile (windowmaker, orig_wmaker_fname, YES))
+	 warning (_("New WindowMaker configuration file `%s' created."),
+		  orig_wmaker_fname);
       else
-	 error (_("Can't generate configuration file `%s'."), wmpath);
+	 error (_("Can't generate configuration file `%s'."), orig_wmaker_fname);
    }
    else
    {
-      char		*orig;		/* original filename */
-      proplist_t	*porig;		/* original fname in PropList format */
-      char		*new;		/* backup filename */
-      proplist_t	*pnew;		/* backup fname in PropList format */
+      char *new = g_strconcat (orig_wmaker_fname,
+			       ".bak", NULL); /* backup filename */
 
       /*
        *  Generate backup file "'path'.bak"
        */
-      porig = PLGetFilename (windowmaker);
-      orig  = PLGetString (porig);
-      new   = g_strconcat (orig, ".bak", NULL);
-      pnew  = PLMakeString (new);
-      PLSetFilename (windowmaker, pnew);
-      if (PLSave (windowmaker, YES))
+      if (WMWritePropListToFile (windowmaker, new, YES))
 	 message (_("Backupfile `%s' generated."), new);
       else
 	 error (_("Can't write backupfile `%s'."), new);
-      PLSetFilename (windowmaker, porig);
-      PLRelease (pnew);
       Free (new);
 
-      PLSetFilename (global_windowmaker, porig);
-      PLMergeDictionaries(global_windowmaker, windowmaker);
-      PLRelease (windowmaker);
+      WMMergePLDictionaries (global_windowmaker, windowmaker, True /*recurse*/);
       windowmaker = global_windowmaker;
    }
-   Free (wmpath);
    
    /*
     *  Fill WindowMaker attributes not defined by the user with system defaults
     */
    {
-      proplist_t *keys  = PLGetAllDictionaryKeys (wmconfig);
-      proplist_t *pldef = PLMakeString ("Default");
+      proplist_t keys  = WMGetPLDictionaryKeys (wmconfig);
+      proplist_t pldef = WMCreatePLString ("Default");
       unsigned	 n;
       
-      for (n = 0; n < PLGetNumberOfElements (keys); n++)
+      for (n = 0; n < WMGetPropListItemCount (keys); n++)
       {
-	 proplist_t *attribute = PLGetArrayElement (keys, n);
+	 proplist_t attribute = WMGetFromPLArray (keys, n);
 	 
-	 if (!PLGetDictionaryEntry (windowmaker, attribute)) /* not defined */
+	 if (!WMGetFromPLDictionary (windowmaker, attribute)) /* not defined */
 	 {
-	    proplist_t *apl = PLGetDictionaryEntry (wmconfig, attribute);
-	    proplist_t *val = PLGetDictionaryEntry (apl, pldef);
+	    proplist_t apl = WMGetFromPLDictionary (wmconfig, attribute);
+	    proplist_t val = WMGetFromPLDictionary (apl, pldef);
 	    
-	    PLInsertDictionaryEntry (windowmaker, attribute, val);
+	    WMPutInPLDictionary (windowmaker, attribute, val);
 	 }
       }
 
-      PLRelease (pldef);
-      PLRelease (keys);
+      WMReleasePropList (pldef);
+      WMReleasePropList (keys);
    }
 
    root_window (conffile,sections, sections_restriction_type, no_inet, 
 		window, wmconfig, wmpanel, windowmaker);
 
-   PLRelease (wmakerconf);
-   PLRelease (windowmaker);
+   WMReleasePropList (wmakerconf);
+   WMReleasePropList (windowmaker);
    if (orig_rootmenu)
-      PLRelease (orig_rootmenu);
-   PLRelease (orig_wmaker);
-   PLRelease (plist_changed);
-   PLRelease (pl_yes);
+      WMReleasePropList (orig_rootmenu);
+   WMReleasePropList (orig_wmaker);
+   WMReleasePropList (plist_changed);
+   WMReleasePropList (pl_yes);
 
+   Free (orig_rootmenu_fname);
+   Free (orig_wmaker_fname);
+   
    g_mem_profile ();
    
    return 0;
 }
 
-static BOOL
-StringCompareHook (proplist_t pl1, proplist_t pl2)
-{
-   return strcaseeq (PLGetString(pl1), PLGetString(pl2));
-}
-
 static GtkWidget *
 make_log_window (void)
 {
